@@ -89,13 +89,22 @@ DEFobjCurrIf(glbl)
 DEFobjCurrIf(net)
 DEFobjCurrIf(prop)
 DEFobjCurrIf(datetime)
-DEFobjCurrIf(errmsg)
 DEFobjCurrIf(ruleset)
 DEFobjCurrIf(statsobj)
 
 /* forward references */
 static void * wrkr(void *myself);
 
+/* unfortunately, on some platforms EAGAIN == EWOULDBOLOCK and so checking against
+ * both of them generates a gcc 8 warning for this reason. We do not want to disable
+ * the warning, so we need to work around this via a macro.
+ */
+#if EAGAIN == EWOULDBLOCK
+	#define CHK_EAGAIN_EWOULDBLOCK (errno == EAGAIN)
+#else
+	#define CHK_EAGAIN_EWOULDBLOCK (errno == EAGAIN | errno == EWOULDBLOCK)
+#endif /* #if EAGAIN == EWOULDBOLOCK */
+
 #define DFLT_wrkrMax 2
 #define DFLT_inlineDispatchThreshold 1
 
@@ -136,6 +145,7 @@ struct instanceConf_s {
 	sbool multiLine;
 	uint8_t compressionMode;
 	uchar *pszBindPort;		/* port to bind to */
+	uchar *pszLstnPortFileName;	/* Name of the file with dynamic port used by testbench*/
 	uchar *pszBindAddr;		/* IP to bind socket to */
 	uchar *pszBindPath;     /* Path to bind socket to */
 	uchar *pszBindRuleset;		/* name of ruleset to bind to */
@@ -153,7 +163,7 @@ struct instanceConf_s {
 	int ratelimitInterval;
 	int ratelimitBurst;
 	uchar *startRegex;
-	regex_t end_preg;	/* compiled version of startRegex */
+	regex_t start_preg;	/* compiled version of startRegex */
 	struct instanceConf_s *next;
 };
 
@@ -212,6 +222,7 @@ static struct cnfparamdescr inppdescr[] = {
 	{ "ratelimit.interval", eCmdHdlrInt, 0 },
 	{ "ratelimit.burst", eCmdHdlrInt, 0 },
 	{ "multiline", eCmdHdlrBinary, 0 },
+	{ "listenportfilename", eCmdHdlrString, 0 },
 	{ "socketbacklog", eCmdHdlrInt, 0 }
 };
 static struct cnfparamblk inppblk =
@@ -245,6 +256,7 @@ struct ptcpsrv_s {
 	int	bFailOnPerms;	/* fail creation if chown fails? */
 	sbool bUnixSocket;
 	int socketBacklog;
+	uchar *pszLstnPortFileName;
 	int iAddtlFrameDelim;
 	sbool multiLine;
 	int iKeepAliveIntvl;
@@ -400,6 +412,8 @@ destructSrv(ptcpsrv_t *pSrv)
 		free(pSrv->pszInputName);
 	if(pSrv->port != NULL)
 		free(pSrv->port);
+	if(pSrv->pszLstnPortFileName)
+		free(pSrv->pszLstnPortFileName);
 	if(pSrv->path != NULL)
 		free(pSrv->path);
 	if(pSrv->lstnIP != NULL)
@@ -423,7 +437,7 @@ static rsRetVal startupUXSrv(ptcpsrv_t *pSrv) {
 
 	sock = socket(AF_UNIX, SOCK_STREAM, 0);
 	if(sock < 0) {
-		errmsg.LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: error creating unix socket");
+		LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: error creating unix socket");
 		ABORT_FINALIZE(RS_RET_ERR_CRE_AFUX);
 	}
 
@@ -441,30 +455,32 @@ static rsRetVal startupUXSrv(ptcpsrv_t *pSrv) {
 	}
 
 	if (sockflags == -1) {
-		errmsg.LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: error setting fcntl(O_NONBLOCK) on unix socket");
+		LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: error setting fcntl(O_NONBLOCK) on unix socket");
 		ABORT_FINALIZE(RS_RET_ERR_CRE_AFUX);
 	}
 
 	if (bind(sock, (struct sockaddr *)&local, SUN_LEN(&local)) < 0) {
-		errmsg.LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: error while binding unix socket");
+		LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: error while binding unix socket");
 		ABORT_FINALIZE(RS_RET_ERR_CRE_AFUX);
 	}
 
+//	dbgprintf("pascal: listenportfilename = %s\n", pSrv->pszLstnPortFileName);
+
 	if (listen(sock, pSrv->socketBacklog) < 0) {
-		errmsg.LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: unix socket listen error");
+		LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: unix socket listen error");
 		ABORT_FINALIZE(RS_RET_ERR_CRE_AFUX);
 	}
 
 	if(chown(local.sun_path, pSrv->fileUID, pSrv->fileGID) != 0) {
 		if(pSrv->bFailOnPerms) {
-			errmsg.LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: unix socket chown error");
+			LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: unix socket chown error");
 			ABORT_FINALIZE(RS_RET_ERR_CRE_AFUX);
 		}
 	}
 
 	if(chmod(local.sun_path, pSrv->fCreateMode) != 0) {
 		if(pSrv->bFailOnPerms) {
-			errmsg.LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: unix socket chmod error");
+			LogError(errno, RS_RET_ERR_CRE_AFUX, "imptcp: unix socket chmod error");
 			ABORT_FINALIZE(RS_RET_ERR_CRE_AFUX);
 		}
 	}
@@ -485,6 +501,8 @@ finalize_it:
  * Does NOT yet accept/process any incoming data (but binds ports). Hint: this
  * code is to be executed before dropping privileges.
  */
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-align"
 static rsRetVal
 startupSrv(ptcpsrv_t *pSrv)
 {
@@ -531,7 +549,7 @@ startupSrv(ptcpsrv_t *pSrv)
 				 * also be ignored...
 				 */
 			}
-                        continue;
+			continue;
 		}
 
 		if(r->ai_family == AF_INET6) {
@@ -576,18 +594,18 @@ startupSrv(ptcpsrv_t *pSrv)
 		 * could flood our log files by sending us tons of ICMP errors.
 		 */
 #if !defined (_AIX)
-#ifndef BSD	
+#ifndef BSD
 		if(net.should_use_so_bsdcompat()) {
 			if (setsockopt(sock, SOL_SOCKET, SO_BSDCOMPAT,
 					(char *) &on, sizeof(on)) < 0) {
-				errmsg.LogError(errno, NO_ERRCODE, "TCP setsockopt(BSDCOMPAT)");
-                                close(sock);
+				LogError(errno, NO_ERRCODE, "TCP setsockopt(BSDCOMPAT)");
+				close(sock);
 				sock = -1;
 				continue;
 			}
 		}
 #endif
-#endif 
+#endif
 		if( (bind(sock, r->ai_addr, r->ai_addrlen) < 0)
 #ifndef IPV6_V6ONLY
 		     && (errno != EADDRINUSE)
@@ -596,12 +614,32 @@ startupSrv(ptcpsrv_t *pSrv)
 			/* TODO: check if *we* bound the socket - else we *have* an error! */
 			char errStr[1024];
 			rs_strerror_r(errno, errStr, sizeof(errStr));
+			LogError(errno, NO_ERRCODE, "Error while binding tcp socket");
 			dbgprintf("error %d while binding tcp socket: %s\n", errno, errStr);
 			close(sock);
 			sock = -1;
 			continue;
 		}
 
+		if(pSrv->pszLstnPortFileName) {
+			FILE *fp;
+			if(getsockname(sock, r->ai_addr, &r->ai_addrlen) == -1) {
+				LogError(errno, NO_ERRCODE, "imptcp: ListenPortFileName: getsockname:"
+						"error while trying to get socket");
+			}
+			if((fp = fopen((const char*)pSrv->pszLstnPortFileName, "w+")) == NULL) {
+				LogError(errno, RS_RET_IO_ERROR, "imptcp: ListenPortFileName: "
+						"error while trying to open file");
+				ABORT_FINALIZE(RS_RET_IO_ERROR);
+			}
+			if(isIPv6) {
+				fprintf(fp, "%d", ntohs((((struct sockaddr_in6*)r->ai_addr)->sin6_port)));
+			} else {
+				fprintf(fp, "%d", ntohs((((struct sockaddr_in*)r->ai_addr)->sin_port)));
+			}
+			fclose(fp);
+		}
+
 		if(listen(sock, pSrv->socketBacklog) < 0) {
 			DBGPRINTF("tcp listen error %d, suspending\n", errno);
 			close(sock);
@@ -639,7 +677,7 @@ finalize_it:
 
 	RETiRet;
 }
-
+#pragma GCC diagnostic pop
 
 /* Set pRemHost based on the address provided. This is to be called upon accept()ing
  * a connection request. It must be provided by the socket we received the
@@ -753,7 +791,7 @@ EnableKeepAlive(ptcplstn_t *pLstn, int sock)
 	ret = -1;
 #	endif
 	if(ret < 0) {
-		errmsg.LogError(ret, NO_ERRCODE, "imptcp cannot set keepalive probes - ignored");
+		LogError(ret, NO_ERRCODE, "imptcp cannot set keepalive probes - ignored");
 	}
 
 #	if defined(TCP_KEEPCNT)
@@ -768,7 +806,7 @@ EnableKeepAlive(ptcplstn_t *pLstn, int sock)
 	ret = -1;
 #	endif
 	if(ret < 0) {
-		errmsg.LogError(ret, NO_ERRCODE, "imptcp cannot set keepalive time - ignored");
+		LogError(ret, NO_ERRCODE, "imptcp cannot set keepalive time - ignored");
 	}
 
 #	if defined(TCP_KEEPCNT)
@@ -783,7 +821,7 @@ EnableKeepAlive(ptcplstn_t *pLstn, int sock)
 	ret = -1;
 #	endif
 	if(ret < 0) {
-		errmsg.LogError(errno, NO_ERRCODE, "imptcp cannot set keepalive intvl - ignored");
+		LogError(errno, NO_ERRCODE, "imptcp cannot set keepalive intvl - ignored");
 	}
 
 	dbgprintf("KEEPALIVE enabled for socket %d\n", sock);
@@ -809,7 +847,7 @@ AcceptConnReq(ptcplstn_t *const pLstn, int *const newSock, prop_t **peerName, pr
 	*peerName = NULL; /* ensure we know if we don't have one! */
 	iNewSock = accept(pLstn->sock, (struct sockaddr*) &addr, &addrlen);
 	if(iNewSock < 0) {
-		if(errno == EAGAIN || errno == EWOULDBLOCK || errno == EMFILE)
+		if(CHK_EAGAIN_EWOULDBLOCK || errno == EMFILE)
 			ABORT_FINALIZE(RS_RET_NO_MORE_DATA);
 		LogError(errno, RS_RET_ACCEPT_ERR, "error accepting connection "
 			    "on listen socket %d", pLstn->sock);
@@ -873,7 +911,7 @@ finalize_it:
  * It does some common processing, including resetting the various
  * state variables to a "processed" state.
  * Note that this function is also called if we had a buffer overflow
- * due to a too-long message. So far, there is no indication this 
+ * due to a too-long message. So far, there is no indication this
  * happened and it may be worth thinking about different handling
  * of this case (what obviously would require a change to this
  * function or some related code).
@@ -952,7 +990,7 @@ processDataRcvd_regexFraming(ptcpsess_t *const __restrict__ pThis,
 	if(c == '\n') {
 		pThis->iCurrLine = pThis->iMsg;
 	} else {
-		const int isMatch = !regexec(&inst->end_preg, (char*)pThis->pMsg+pThis->iCurrLine, 0, NULL, 0);
+		const int isMatch = !regexec(&inst->start_preg, (char*)pThis->pMsg+pThis->iCurrLine, 0, NULL, 0);
 		if(isMatch) {
 			DBGPRINTF("regex match (%d), framing line: %s\n", pThis->iCurrLine, pThis->pMsg);
 			strcpy((char*)pThis->pMsg_save, (char*) pThis->pMsg+pThis->iCurrLine);
@@ -1029,13 +1067,13 @@ processDataRcvd(ptcpsess_t *const __restrict__ pThis,
 			prop.GetString(pThis->peerName, &propPeerName, &lenPeerName);
 			prop.GetString(pThis->peerIP, &propPeerIP, &lenPeerIP);
 			if(c != ' ') {
-				errmsg.LogError(0, NO_ERRCODE, "Framing Error in received TCP message "
+				LogError(0, NO_ERRCODE, "Framing Error in received TCP message "
 						"from peer: (hostname) %s, (ip) %s: delimiter is not "
 						"SP but has ASCII value %d.", propPeerName, propPeerIP, c);
 			}
 			if(pThis->iOctetsRemain < 1) {
 				/* TODO: handle the case where the octet count is 0! */
-				errmsg.LogError(0, NO_ERRCODE, "Framing Error in received TCP message"
+				LogError(0, NO_ERRCODE, "Framing Error in received TCP message"
 						" from peer: (hostname) %s, (ip) %s: invalid octet count %d.",
 						propPeerName, propPeerIP, pThis->iOctetsRemain);
 				pThis->eFraming = TCP_FRAMING_OCTET_STUFFING;
@@ -1045,13 +1083,13 @@ processDataRcvd(ptcpsess_t *const __restrict__ pThis,
 				 */
 				DBGPRINTF("truncating message with %d octets - max msg size is %d\n",
 					  pThis->iOctetsRemain, iMaxLine);
-				errmsg.LogError(0, NO_ERRCODE, "received oversize message from peer: "
+				LogError(0, NO_ERRCODE, "received oversize message from peer: "
 						"(hostname) %s, (ip) %s: size is %d bytes, max msg "
 						"size is %d, truncating...", propPeerName, propPeerIP,
 						pThis->iOctetsRemain, iMaxLine);
 			}
 			if(pThis->iOctetsRemain > pThis->pLstn->pSrv->maxFrameSize) {
-				errmsg.LogError(0, NO_ERRCODE, "Framing Error in received TCP message "
+				LogError(0, NO_ERRCODE, "Framing Error in received TCP message "
 						"from peer: (hostname) %s, (ip) %s: frame too large: %d, "
 						"change to octet stuffing", propPeerName, propPeerIP,
 						pThis->iOctetsRemain);
@@ -1311,7 +1349,7 @@ addEPollSock(epolld_type_t typ, void *ptr, int sock, epolld_t **pEpd)
 	if(epoll_ctl(epollfd, EPOLL_CTL_ADD, sock, &(epd->ev)) != 0) {
 		char errStr[1024];
 		int eno = errno;
-		errmsg.LogError(0, RS_RET_EPOLL_CTL_FAILED, "os error (%d) during epoll ADD: %s",
+		LogError(0, RS_RET_EPOLL_CTL_FAILED, "os error (%d) during epoll ADD: %s",
 			        eno, rs_strerror_r(eno, errStr, sizeof(errStr)));
 		ABORT_FINALIZE(RS_RET_EPOLL_CTL_FAILED);
 	}
@@ -1321,7 +1359,7 @@ addEPollSock(epolld_type_t typ, void *ptr, int sock, epolld_t **pEpd)
 finalize_it:
 	if(iRet != RS_RET_OK) {
 		if (epd != NULL) {
-			errmsg.LogError(0, RS_RET_INTERNAL_ERROR, "error: could not initialize mutex for ptcp "
+			LogError(0, RS_RET_INTERNAL_ERROR, "error: could not initialize mutex for ptcp "
 			"connection for socket: %d", sock);
 		}
 		free(epd);
@@ -1330,7 +1368,7 @@ finalize_it:
 }
 
 
-/* add a listener to the server 
+/* add a listener to the server
  */
 static rsRetVal
 addLstn(ptcpsrv_t *pSrv, int sock, int isIPv6)
@@ -1363,13 +1401,13 @@ addLstn(ptcpsrv_t *pSrv, int sock, int isIPv6)
 		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(pLstn->ctrSubmit)));
 	STATSCOUNTER_INIT(pLstn->ctrSessOpen, pLstn->mutCtrSessOpen);
 	CHKiRet(statsobj.AddCounter(pLstn->stats, UCHAR_CONSTANT("sessions.opened"),
-		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(pLstn->ctrSessClose)));
+		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(pLstn->ctrSessOpen)));
 	STATSCOUNTER_INIT(pLstn->ctrSessOpenErr, pLstn->mutCtrSessOpenErr);
 	CHKiRet(statsobj.AddCounter(pLstn->stats, UCHAR_CONSTANT("sessions.openfailed"),
-		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(pLstn->ctrSessClose)));
+		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(pLstn->ctrSessOpenErr)));
 	STATSCOUNTER_INIT(pLstn->ctrSessClose, pLstn->mutCtrSessClose);
 	CHKiRet(statsobj.AddCounter(pLstn->stats, UCHAR_CONSTANT("sessions.closed"),
-		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(pLstn->ctrSessOpen)));
+		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(pLstn->ctrSessClose)));
 	/* the following counters are not protected by mutexes; we accept
 	 * that they may not be 100% correct */
 	pLstn->rcvdBytes = 0,
@@ -1402,7 +1440,7 @@ finalize_it:
 }
 
 
-/* add a session to the server 
+/* add a session to the server
  */
 static rsRetVal
 addSess(ptcplstn_t *pLstn, int sock, prop_t *peerName, prop_t *peerIP)
@@ -1583,6 +1621,7 @@ createInstance(instanceConf_t **pinst)
 	inst->compressionMode = COMPRESS_SINGLE_MSG;
 	inst->multiLine = 0;
 	inst->socketBacklog = 5;
+	inst->pszLstnPortFileName = NULL;
 
 	/* node created, let's add to config */
 	if(loadModConf->tail == NULL) {
@@ -1598,7 +1637,7 @@ finalize_it:
 }
 
 
-/* This function is called when a new listener instace shall be added to 
+/* This function is called when a new listener instace shall be added to
  * the current config object via the legacy config system. It just shuffles
  * all parameters to the listener in-memory instance.
  */
@@ -1674,6 +1713,7 @@ addListner(modConfData_t __attribute__((unused)) *modConf, instanceConf_t *inst)
 	pSrv->iAddtlFrameDelim = inst->iAddtlFrameDelim;
 	pSrv->multiLine = inst->multiLine;
 	pSrv->socketBacklog = inst->socketBacklog;
+	pSrv->pszLstnPortFileName = inst->pszLstnPortFileName;
 	pSrv->maxFrameSize = inst->maxFrameSize;
 	if (inst->pszBindAddr == NULL) {
 		pSrv->lstnIP = NULL;
@@ -1715,7 +1755,7 @@ addListner(modConfData_t __attribute__((unused)) *modConf, instanceConf_t *inst)
 
 finalize_it:
 	if(iRet != RS_RET_OK) {
-		errmsg.LogError(0, NO_ERRCODE, "error %d trying to add listener", iRet);
+		LogError(0, NO_ERRCODE, "error %d trying to add listener", iRet);
 		if(pSrv != NULL) {
 			destructSrv(pSrv);
 		}
@@ -1761,12 +1801,12 @@ stopWorkerPool(void)
 		pthread_join(wrkrInfo[i].tid, NULL);
 		DBGPRINTF("imptcp: info: worker %d was called %llu times\n", i, wrkrInfo[i].numCalled);
 	}
-    free(wrkrInfo);
+	free(wrkrInfo);
 }
 
 
 
-/* start up all listeners 
+/* start up all listeners
  * This is a one-time stop once the module is set to start.
  */
 static rsRetVal
@@ -1795,7 +1835,7 @@ startupServers(void)
 	DBGPRINTF("imptcp: %d out of %d servers started successfully\n", iOK, iAll);
 	if(iOK == 0)	/* iff all fails, we report an error */
 		iRet = lastErr;
-		
+
 	RETiRet;
 }
 
@@ -1866,13 +1906,13 @@ sessActivity(ptcpsess_t *pSess, int *continue_polling)
 			}
 			*continue_polling = 0;
 			if(bEmitOnClose) {
-				errmsg.LogError(0, RS_RET_PEER_CLOSED_CONN, "imptcp session %d closed by "
+				LogError(0, RS_RET_PEER_CLOSED_CONN, "imptcp session %d closed by "
 					  	"remote peer %s.", remsock, peerName);
 			}
 			CHKiRet(closeSess(pSess)); /* close may emit more messages in strmzip mode! */
 			break;
 		} else {
-			if(errno == EAGAIN || errno == EWOULDBLOCK)
+			if(CHK_EAGAIN_EWOULDBLOCK)
 				break;
 			DBGPRINTF("imptcp: error on session socket %d - closed.\n", pSess->sock);
 			*continue_polling = 0;
@@ -1904,7 +1944,7 @@ processWorkItem(epolld_t *epd)
 		sessActivity((ptcpsess_t *) epd->ptr, &continue_polling);
 		break;
 	default:
-		errmsg.LogError(0, RS_RET_INTERNAL_ERROR,
+		LogError(0, RS_RET_INTERNAL_ERROR,
 						"error: invalid epolld_type_t %d after epoll", epd->typ);
 		break;
 	}
@@ -1947,7 +1987,7 @@ destroyIoQ(void)
 	while (!STAILQ_EMPTY(&io_q.q)) {
 		n = STAILQ_FIRST(&io_q.q);
 		STAILQ_REMOVE_HEAD(&io_q.q, link);
-		errmsg.LogError(0, RS_RET_INTERNAL_ERROR, "imptcp: discarded enqueued io-work to allow shutdown "
+		LogError(0, RS_RET_INTERNAL_ERROR, "imptcp: discarded enqueued io-work to allow shutdown "
 								"- ignored");
 		free(n);
 	}
@@ -1961,12 +2001,13 @@ static rsRetVal
 enqueueIoWork(epolld_t *epd, int dispatchInlineIfQueueFull) {
 	io_req_t *n;
 	int dispatchInline;
+	int inlineDispatchThreshold;
 	DEFiRet;
 	
 	CHKmalloc(n = malloc(sizeof(io_req_t)));
 	n->epd = epd;
 	
-	int inlineDispatchThreshold = DFLT_inlineDispatchThreshold * runModConf->wrkrMax;
+	inlineDispatchThreshold = DFLT_inlineDispatchThreshold * runModConf->wrkrMax;
 	dispatchInline = 0;
 	
 	pthread_mutex_lock(&io_q.mut);
@@ -1988,7 +2029,7 @@ enqueueIoWork(epolld_t *epd, int dispatchInlineIfQueueFull) {
 finalize_it:
 	if (iRet != RS_RET_OK) {
 		if (n == NULL) {
-			errmsg.LogError(0, iRet, "imptcp: couldn't allocate memory to enqueue io-request - ignored");
+			LogError(0, iRet, "imptcp: couldn't allocate memory to enqueue io-request - ignored");
 		}
 	}
 	RETiRet;
@@ -2162,6 +2203,8 @@ CODESTARTnewInpInst
 			inst->ratelimitInterval = (int) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "multiline")) {
 			inst->multiLine = (sbool) pvals[i].val.d.n;
+		} else if(!strcmp(inppblk.descr[i].name, "listenportfilename")) {
+			inst->pszLstnPortFileName =  (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
 		} else if(!strcmp(inppblk.descr[i].name, "socketbacklog")) {
 			inst->socketBacklog = (int) pvals[i].val.d.n;
 		} else {
@@ -2178,10 +2221,10 @@ CODESTARTnewInpInst
 	}
 
 	if(inst->startRegex != NULL) {
-		const int errcode = regcomp(&inst->end_preg, (char*)inst->startRegex, REG_EXTENDED);
+		const int errcode = regcomp(&inst->start_preg, (char*)inst->startRegex, REG_EXTENDED);
 		if(errcode != 0) {
 			char errbuff[512];
-			regerror(errcode, &inst->end_preg, errbuff, sizeof(errbuff));
+			regerror(errcode, &inst->start_preg, errbuff, sizeof(errbuff));
 			parser_errmsg("imptcp: error in framing.delimiter.regex expansion: %s", errbuff);
 			ABORT_FINALIZE(RS_RET_ERR);
 		}
@@ -2212,7 +2255,7 @@ BEGINsetModCnf
 CODESTARTsetModCnf
 	pvals = nvlstGetParams(lst, &modpblk, NULL);
 	if(pvals == NULL) {
-		errmsg.LogError(0, RS_RET_MISSING_CNFPARAMS, "imptcp: error processing module "
+		LogError(0, RS_RET_MISSING_CNFPARAMS, "imptcp: error processing module "
 				"config parameters [module(...)]");
 		ABORT_FINALIZE(RS_RET_MISSING_CNFPARAMS);
 	}
@@ -2267,7 +2310,7 @@ ENDendCnfLoad
 static inline void
 std_checkRuleset_genErrMsg(__attribute__((unused)) modConfData_t *modConf, instanceConf_t *inst)
 {
-	errmsg.LogError(0, NO_ERRCODE, "imptcp: ruleset '%s' for port %s not found - "
+	LogError(0, NO_ERRCODE, "imptcp: ruleset '%s' for port %s not found - "
 			"using default ruleset instead", inst->pszBindRuleset,
 			inst->pszBindPort);
 }
@@ -2291,7 +2334,7 @@ CODESTARTactivateCnfPrePrivDrop
 		addListner(pModConf, inst);
 	}
 	if(pSrvRoot == NULL) {
-		errmsg.LogError(0, RS_RET_NO_LSTN_DEFINED, "imptcp: no ptcp server defined, module can not run.");
+		LogError(0, RS_RET_NO_LSTN_DEFINED, "imptcp: no ptcp server defined, module can not run.");
 		ABORT_FINALIZE(RS_RET_NO_RUN);
 	}
 
@@ -2310,7 +2353,7 @@ CODESTARTactivateCnfPrePrivDrop
 	}
 
 	if(epollfd < 0) {
-		errmsg.LogError(0, RS_RET_EPOLL_CR_FAILED, "error: epoll_create() failed");
+		LogError(0, RS_RET_EPOLL_CR_FAILED, "error: epoll_create() failed");
 		ABORT_FINALIZE(RS_RET_NO_RUN);
 	}
 
@@ -2338,7 +2381,7 @@ CODESTARTfreeCnf
 		free(inst->pszInputName);
 		free(inst->dfltTZ);
 		if(inst->startRegex != NULL) {
-			regfree(&inst->end_preg);
+			regfree(&inst->start_preg);
 			free(inst->startRegex);
 		}
 		del = inst;
@@ -2442,7 +2485,6 @@ CODESTARTmodExit
 	objRelease(prop, CORE_COMPONENT);
 	objRelease(net, LM_NET_FILENAME);
 	objRelease(datetime, CORE_COMPONENT);
-	objRelease(errmsg, CORE_COMPONENT);
 	objRelease(ruleset, CORE_COMPONENT);
 ENDmodExit
 
@@ -2495,7 +2537,6 @@ CODEmodInit_QueryRegCFSLineHdlr
 	CHKiRet(objUse(statsobj, CORE_COMPONENT));
 	CHKiRet(objUse(prop, CORE_COMPONENT));
 	CHKiRet(objUse(net, LM_NET_FILENAME));
-	CHKiRet(objUse(errmsg, CORE_COMPONENT));
 	CHKiRet(objUse(datetime, CORE_COMPONENT));
 	CHKiRet(objUse(ruleset, CORE_COMPONENT));
 
