@@ -34,6 +34,7 @@
 #include <sys/socket.h>
 #include <pthread.h>
 #include <signal.h>
+#include <poll.h>
 #ifdef HAVE_SYS_EPOLL_H
 #	include <sys/epoll.h>
 #endif
@@ -66,7 +67,6 @@ MODULE_CNFNAME("imudp")
 
 /* Module static data */
 DEF_IMOD_STATIC_DATA
-DEFobjCurrIf(errmsg)
 DEFobjCurrIf(glbl)
 DEFobjCurrIf(net)
 DEFobjCurrIf(datetime)
@@ -152,6 +152,7 @@ struct modConfData_s {
 	int batchSize;			/* max nbr of input batch --> also recvmmsg() max count */
 	int8_t wrkrMax;			/* max nbr of worker threads */
 	sbool configSetViaV2Method;
+	sbool bPreserveCase;	/* preserves the case of fromhost; "off" by default */
 };
 static modConfData_t *loadModConf = NULL;/* modConf ptr to use for the current load process */
 static modConfData_t *runModConf = NULL;/* modConf ptr to use for the current load process */
@@ -162,7 +163,8 @@ static struct cnfparamdescr modpdescr[] = {
 	{ "schedulingpriority", eCmdHdlrInt, 0 },
 	{ "batchsize", eCmdHdlrInt, 0 },
 	{ "threads", eCmdHdlrPositiveInt, 0 },
-	{ "timerequery", eCmdHdlrInt, 0 }
+	{ "timerequery", eCmdHdlrInt, 0 },
+	{ "preservecase", eCmdHdlrBinary, 0 }
 };
 static struct cnfparamblk modpblk =
 	{ CNFPARAMBLK_VERSION,
@@ -232,7 +234,7 @@ finalize_it:
 	RETiRet;
 }
 
-/* This function is called when a new listener instace shall be added to 
+/* This function is called when a new listener instace shall be added to
  * the current config object via the legacy config system. It just shuffles
  * all parameters to the listener in-memory instance.
  * rgerhards, 2011-05-04
@@ -340,7 +342,7 @@ addListner(instanceConf_t *inst)
 			CHKiRet(statsobj.AddCounter(newlcnfinfo->stats, UCHAR_CONSTANT("disallowed"),
 				ctrType_IntCtr, CTR_FLAG_RESETTABLE, &(newlcnfinfo->ctrDisallowed)));
 			CHKiRet(statsobj.ConstructFinalize(newlcnfinfo->stats));
-			/* link to list. Order must be preserved to take care for 
+			/* link to list. Order must be preserved to take care for
 			 * conflicting matches.
 			 */
 			if(lcnfRoot == NULL)
@@ -353,7 +355,7 @@ addListner(instanceConf_t *inst)
 			}
 		}
 	} else {
-		errmsg.LogError(0, NO_ERRCODE, "imudp: Could not create udp listener,"
+		LogError(0, NO_ERRCODE, "imudp: Could not create udp listener,"
 				" ignoring port %s bind-address %s.",
 				port, bindAddr);
 	}
@@ -384,7 +386,7 @@ finalize_it:
 static inline void
 std_checkRuleset_genErrMsg(__attribute__((unused)) modConfData_t *modConf, instanceConf_t *inst)
 {
-	errmsg.LogError(0, NO_ERRCODE, "imudp: ruleset '%s' for %s:%s not found - "
+	LogError(0, NO_ERRCODE, "imudp: ruleset '%s' for %s:%s not found - "
 			"using default ruleset instead", inst->pszBindRuleset,
 			inst->pszBindAddr == NULL ? "*" : (char*) inst->pszBindAddr,
 			inst->pszBindPort);
@@ -425,7 +427,7 @@ processPacket(struct lstn_s *lstn, struct sockaddr_storage *frominetPrev, int *p
 				DBGPRINTF("msg is not from an allowed sender\n");
 				STATSCOUNTER_INC(lstn->ctrDisallowed, lstn->mutCtrDisallowed);
 				if(glbl.GetOption_DisallowWarning) {
-					errmsg.LogError(0, NO_ERRCODE,
+					LogError(0, NO_ERRCODE,
 						"imudp: UDP message from disallowed sender discarded");
 				}
 			}
@@ -447,8 +449,12 @@ processPacket(struct lstn_s *lstn, struct sockaddr_storage *frominetPrev, int *p
 		if(lstn->dfltTZ != NULL)
 			MsgSetDfltTZ(pMsg, (char*) lstn->dfltTZ);
 		pMsg->msgFlags  = NEEDS_PARSING | PARSE_HOSTNAME | NEEDS_DNSRESOL;
-		if(*pbIsPermitted == 2)
-			pMsg->msgFlags  |= NEEDS_ACLCHK_U; /* request ACL check after resolution */
+		if(*pbIsPermitted == 2) {
+			pMsg->msgFlags |= NEEDS_ACLCHK_U; /* request ACL check after resolution */
+		}
+		if(runModConf->bPreserveCase) {
+			pMsg->msgFlags |= PRESERVE_CASE; /* preserve case of fromhost */
+		}
 		CHKiRet(msgSetFromSockinfo(pMsg, frominet));
 		CHKiRet(ratelimitAddMsg(lstn->ratelimiter, multiSub, pMsg));
 		STATSCOUNTER_INC(lstn->ctrSubmit, lstn->mutCtrSubmit);
@@ -479,7 +485,7 @@ int *pbIsPermitted)
 	DEFiRet;
 	int iNbrTimeUsed;
 	time_t ttGenTime = 0; /* to avoid clang static analyzer false positive */
-		/* note: we do never use this time, because we always get a 
+		/* note: we do never use this time, because we always get a
 		 * requery below on first loop iteration */
 	struct syslogTime stTime;
 	char errStr[1024];
@@ -500,7 +506,7 @@ int *pbIsPermitted)
 		for(i = 0 ; i < runModConf->batchSize ; ++i) {
 			pWrkr->recvmsg_iov[i].iov_base = pWrkr->pRcvBuf+(i*(iMaxLine+1));
 			pWrkr->recvmsg_iov[i].iov_len = iMaxLine;
-			pWrkr->recvmsg_mmh[i].msg_hdr.msg_namelen = sizeof(struct sockaddr_storage); 
+			pWrkr->recvmsg_mmh[i].msg_hdr.msg_namelen = sizeof(struct sockaddr_storage);
 			pWrkr->recvmsg_mmh[i].msg_hdr.msg_name = &(pWrkr->frominet[i]);
 			pWrkr->recvmsg_mmh[i].msg_hdr.msg_iov = &(pWrkr->recvmsg_iov[i]);
 			pWrkr->recvmsg_mmh[i].msg_hdr.msg_iovlen = 1;
@@ -522,7 +528,7 @@ int *pbIsPermitted)
 			if(errno != EINTR && errno != EAGAIN) {
 				rs_strerror_r(errno, errStr, sizeof(errStr));
 				DBGPRINTF("INET socket error: %d = %s.\n", errno, errStr);
-				errmsg.LogError(errno, NO_ERRCODE, "imudp: error receiving on socket: %s", errStr);
+				LogError(errno, NO_ERRCODE, "imudp: error receiving on socket: %s", errStr);
 			}
 			ABORT_FINALIZE(RS_RET_ERR);
 			// this most often is NOT an error, state is not checked by caller!
@@ -588,7 +594,7 @@ int *pbIsPermitted)
 		iov[0].iov_len = iMaxLine;
 		memset(&mh, 0, sizeof(mh));
 		mh.msg_name = &frominet;
-		mh.msg_namelen = sizeof(struct sockaddr_storage); 
+		mh.msg_namelen = sizeof(struct sockaddr_storage);
 		mh.msg_iov = iov;
 		mh.msg_iovlen = 1;
 		lenRcvBuf = recvmsg(lstn->sock, &mh, 0);
@@ -597,7 +603,7 @@ int *pbIsPermitted)
 			if(errno != EINTR && errno != EAGAIN) {
 				rs_strerror_r(errno, errStr, sizeof(errStr));
 				DBGPRINTF("INET socket error: %d = %s.\n", errno, errStr);
-				errmsg.LogError(errno, NO_ERRCODE, "imudp: error receiving on socket: %s", errStr);
+				LogError(errno, NO_ERRCODE, "imudp: error receiving on socket: %s", errStr);
 			}
 			ABORT_FINALIZE(RS_RET_ERR);
 			// this most often is NOT an error, state is not checked by caller!
@@ -626,12 +632,12 @@ finalize_it:
 static rsRetVal
 checkSchedulingPriority(modConfData_t *modConf)
 {
-    	DEFiRet;
+	DEFiRet;
 
 #ifdef HAVE_SCHED_GET_PRIORITY_MAX
 	if(   modConf->iSchedPrio < sched_get_priority_min(modConf->iSchedPolicy)
 	   || modConf->iSchedPrio > sched_get_priority_max(modConf->iSchedPolicy)) {
-		errmsg.LogError(0, NO_ERRCODE,
+		LogError(0, NO_ERRCODE,
 			"imudp: scheduling priority %d out of range (%d - %d)"
 			" for scheduling policy '%s' - ignoring settings",
 			modConf->iSchedPrio,
@@ -646,7 +652,7 @@ finalize_it:
 }
 
 
-/* check scheduling policy string and, if valid, set its 
+/* check scheduling policy string and, if valid, set its
  * numeric equivalent in current load config
  */
 static rsRetVal
@@ -668,7 +674,7 @@ checkSchedulingPolicy(modConfData_t *modConf)
 		modConf->iSchedPolicy = SCHED_OTHER;
 #endif
 	} else {
-		errmsg.LogError(errno, NO_ERRCODE,
+		LogError(errno, NO_ERRCODE,
 			    "imudp: invalid scheduling policy '%s' "
 			    "- ignoring setting", modConf->pszSchedPolicy);
 		ABORT_FINALIZE(RS_RET_ERR_SCHED_PARAMS);
@@ -684,11 +690,11 @@ checkSchedParam(modConfData_t *modConf)
 	DEFiRet;
 
 	if(modConf->pszSchedPolicy != NULL && modConf->iSchedPrio == SCHED_PRIO_UNSET) {
-		errmsg.LogError(0, RS_RET_ERR_SCHED_PARAMS,
+		LogError(0, RS_RET_ERR_SCHED_PARAMS,
 			"imudp: scheduling policy set, but without priority - ignoring settings");
 		ABORT_FINALIZE(RS_RET_ERR_SCHED_PARAMS);
 	} else if(modConf->pszSchedPolicy == NULL && modConf->iSchedPrio != SCHED_PRIO_UNSET) {
-		errmsg.LogError(0, RS_RET_ERR_SCHED_PARAMS,
+		LogError(0, RS_RET_ERR_SCHED_PARAMS,
 			"imudp: scheduling priority set, but without policy - ignoring settings");
 		ABORT_FINALIZE(RS_RET_ERR_SCHED_PARAMS);
 	} else if(modConf->pszSchedPolicy != NULL && modConf->iSchedPrio != SCHED_PRIO_UNSET) {
@@ -699,7 +705,7 @@ checkSchedParam(modConfData_t *modConf)
 		modConf->iSchedPrio = SCHED_PRIO_UNSET; /* prevents doing the activation call */
 	}
 #ifndef HAVE_PTHREAD_SETSCHEDPARAM
-	errmsg.LogError(0, NO_ERRCODE,
+	LogError(0, NO_ERRCODE,
 		"imudp: cannot set thread scheduling policy, "
 		"pthread_setschedparam() not available");
 	ABORT_FINALIZE(RS_RET_ERR_SCHED_PARAMS);
@@ -731,7 +737,7 @@ setSchedParams(modConfData_t *modConf)
 		  modConf->pszSchedPolicy, modConf->iSchedPrio);
 	err = pthread_setschedparam(pthread_self(), modConf->iSchedPolicy, &sparam);
 	if(err != 0) {
-		errmsg.LogError(err, NO_ERRCODE, "imudp: pthread_setschedparam() failed - ignoring");
+		LogError(err, NO_ERRCODE, "imudp: pthread_setschedparam() failed - ignoring");
 	}
 finalize_it:
 #	endif
@@ -774,7 +780,7 @@ rcvMainLoop(struct wrkrInfo_s *const __restrict__ pWrkr)
 		++nLstn;
 
 	if(nLstn == 0) {
-		errmsg.LogError(errno, RS_RET_ERR,
+		LogError(errno, RS_RET_ERR,
 			"imudp error: we have 0 listeners, terminating"
 			"worker thread");
 		ABORT_FINALIZE(RS_RET_ERR);
@@ -806,7 +812,7 @@ rcvMainLoop(struct wrkrInfo_s *const __restrict__ pWrkr)
 			udpEPollEvt[i].data.ptr = lstn;
 			if(epoll_ctl(efd, EPOLL_CTL_ADD,  lstn->sock, &(udpEPollEvt[i])) < 0) {
 				rs_strerror_r(errno, errStr, sizeof(errStr));
-				errmsg.LogError(errno, NO_ERRCODE, "epoll_ctrl failed on fd %d with %s\n",
+				LogError(errno, NO_ERRCODE, "epoll_ctrl failed on fd %d with %s\n",
 					lstn->sock, errStr);
 			}
 		}
@@ -836,61 +842,75 @@ finalize_it:
 }
 #else /* #if HAVE_EPOLL_CREATE1 */
 /* this is the code for the select() interface */
-static rsRetVal
+static rsRetVal ATTR_NONNULL()
 rcvMainLoop(struct wrkrInfo_s *const __restrict__ pWrkr)
 {
 	DEFiRet;
-	int maxfds;
 	int nfds;
-	fd_set readfds;
 	struct sockaddr_storage frominetPrev;
 	int bIsPermitted;
+	int i = 0;
 	struct lstn_s *lstn;
 
+	DBGPRINTF("imudp uses poll() [ex-select]\n");
 	/* start "name caching" algo by making sure the previous system indicator
-	 * is invalidated.
-	 */
+	 * is invalidated. */
 	bIsPermitted = 0;
 	memset(&frominetPrev, 0, sizeof(frominetPrev));
-	DBGPRINTF("imudp uses select()\n");
+
+	/* setup poll() subsystem */
+	int nfd = 0;
+	for(lstn = lcnfRoot ; lstn != NULL ; lstn = lstn->next) {
+		if(lstn->sock != -1) {
+			if(Debug) {
+				net.debugListenInfo(lstn->sock, (char*)"UDP");
+			}
+			++nfd;
+		}
+	}
+	struct pollfd *const pollfds = calloc(nfd, sizeof(struct pollfd));
+	CHKmalloc(pollfds);
+
+	for(lstn = lcnfRoot ; lstn != NULL ; lstn = lstn->next) {
+		assert(i < nfd);
+		if (lstn->sock != -1) {
+			pollfds[i].fd = lstn->sock;
+			pollfds[i].events = POLLIN;
+			++i;
+		}
+	}
 
 	while(1) {
-		/* Add the Unix Domain Sockets to the list of read descriptors.
-		 */
-	        maxfds = 0;
-	        FD_ZERO(&readfds);
-
-		/* Add the UDP listen sockets to the list of read descriptors. */
-		for(lstn = lcnfRoot ; lstn != NULL ; lstn = lstn->next) {
-			if (lstn->sock != -1) {
-				if(Debug)
-					net.debugListenInfo(lstn->sock, (char*)"UDP");
-				FD_SET(lstn->sock, &readfds);
-				if(lstn->sock>maxfds) maxfds=lstn->sock;
-			}
-		}
-		if(Debug) {
-			dbgprintf("--------imUDP calling select, active file descriptors (max %d): ", maxfds);
-			for (nfds = 0; nfds <= maxfds; ++nfds)
-				if(FD_ISSET(nfds, &readfds))
-					dbgprintf("%d ", nfds);
-			dbgprintf("\n");
-		}
-
-		/* wait for io to become ready */
-		nfds = select(maxfds+1, (fd_set *) &readfds, NULL, NULL, NULL);
+		DBGPRINTF("--------imudp calling poll() on %d fds\n", nfd);
+		nfds = poll(pollfds, nfd, -1);
 		if(glbl.GetGlobalInputTermState() == 1)
 			break; /* terminate input! */
 
-		for(lstn = lcnfRoot ; nfds && lstn != NULL ; lstn = lstn->next) {
-			if(FD_ISSET(lstn->sock, &readfds)) {
-		       		processSocket(pWrkr, lstn, &frominetPrev, &bIsPermitted);
-			--nfds; /* indicate we have processed one descriptor */
+		if(nfds < 0) {
+			if(errno == EINTR) {
+				DBGPRINTF("imudp: EINTR occured\n");
+			} else {
+				LogMsg(errno, RS_RET_POLL_ERR, LOG_WARNING, "imudp: poll "
+					"system call failed, may cause further troubles");
 			}
+			nfds = 0;
+		}
+
+		i = 0;
+		for(lstn = lcnfRoot ; nfds && lstn != NULL ; lstn = lstn->next) {
+			assert(i < nfd);
+			if(glbl.GetGlobalInputTermState() == 1)
+				ABORT_FINALIZE(RS_RET_FORCE_TERM); /* terminate input! */
+			if(pollfds[i].revents & POLLIN) {
+		       		processSocket(pWrkr, lstn, &frominetPrev, &bIsPermitted);
+				--nfds;
+			}
+			++i;
 	       }
 	       /* end of a run, back to loop for next recv() */
 	}
 
+finalize_it:
 	RETiRet;
 }
 #endif /* #if HAVE_EPOLL_CREATE1 */
@@ -913,33 +933,33 @@ createListner(es_str_t *port, struct cnfparamvals *pvals)
 			continue;	/* array, handled by caller */
 		} else if(!strcmp(inppblk.descr[i].name, "name")) {
 			if(inst->inputname != NULL) {
-				errmsg.LogError(0, RS_RET_INVALID_PARAMS, "imudp: name and inputname "
+				LogError(0, RS_RET_INVALID_PARAMS, "imudp: name and inputname "
 						"parameter specified - only one can be used");
 				ABORT_FINALIZE(RS_RET_INVALID_PARAMS);
 			}
 			inst->inputname = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
 		} else if(!strcmp(inppblk.descr[i].name, "name.appendport")) {
 			if(bAppendPortUsed) {
-				errmsg.LogError(0, RS_RET_INVALID_PARAMS, "imudp: name.appendport and "
+				LogError(0, RS_RET_INVALID_PARAMS, "imudp: name.appendport and "
 						"inputname.appendport parameter specified - only one can be used");
 				ABORT_FINALIZE(RS_RET_INVALID_PARAMS);
 			}
 			inst->bAppendPortToInpname = (int) pvals[i].val.d.n;
 			bAppendPortUsed = 1;
 		} else if(!strcmp(inppblk.descr[i].name, "inputname")) {
-			errmsg.LogError(0, RS_RET_DEPRECATED , "imudp: deprecated parameter inputname "
+			LogError(0, RS_RET_DEPRECATED , "imudp: deprecated parameter inputname "
 					"used. Suggest to use name instead");
 			if(inst->inputname != NULL) {
-				errmsg.LogError(0, RS_RET_INVALID_PARAMS, "imudp: name and inputname "
+				LogError(0, RS_RET_INVALID_PARAMS, "imudp: name and inputname "
 						"parameter specified - only one can be used");
 				ABORT_FINALIZE(RS_RET_INVALID_PARAMS);
 			}
 			inst->inputname = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
 		} else if(!strcmp(inppblk.descr[i].name, "inputname.appendport")) {
-			errmsg.LogError(0, RS_RET_DEPRECATED , "imudp: deprecated parameter inputname.appendport "
+			LogError(0, RS_RET_DEPRECATED , "imudp: deprecated parameter inputname.appendport "
 					"used. Suggest to use name.appendport instead");
 			if(bAppendPortUsed) {
-				errmsg.LogError(0, RS_RET_INVALID_PARAMS, "imudp: name.appendport and "
+				LogError(0, RS_RET_INVALID_PARAMS, "imudp: name.appendport and "
 						"inputname.appendport parameter specified - only one can be used");
 				ABORT_FINALIZE(RS_RET_INVALID_PARAMS);
 			}
@@ -960,7 +980,7 @@ createListner(es_str_t *port, struct cnfparamvals *pvals)
 		} else if(!strcmp(inppblk.descr[i].name, "rcvbufsize")) {
 			const uint64_t val = pvals[i].val.d.n;
 			if(val > 1024 * 1024 * 1024) {
-				errmsg.LogError(0, RS_RET_MISSING_CNFPARAMS,
+				LogError(0, RS_RET_MISSING_CNFPARAMS,
 					"imudp: rcvbufsize maximum is 1 GiB, using "
 					"default instead");
 			} else {
@@ -1016,6 +1036,7 @@ CODESTARTbeginCnfLoad
 	loadModConf->iTimeRequery = TIME_REQUERY_DFLT;
 	loadModConf->iSchedPrio = SCHED_PRIO_UNSET;
 	loadModConf->pszSchedPolicy = NULL;
+	loadModConf->bPreserveCase = 0; /* off */
 	bLegacyCnfModGlobalsPermitted = 1;
 	/* init legacy config vars */
 	cs.pszBindRuleset = NULL;
@@ -1034,7 +1055,7 @@ BEGINsetModCnf
 CODESTARTsetModCnf
 	pvals = nvlstGetParams(lst, &modpblk, NULL);
 	if(pvals == NULL) {
-		errmsg.LogError(0, RS_RET_MISSING_CNFPARAMS, "imudp: error processing module "
+		LogError(0, RS_RET_MISSING_CNFPARAMS, "imudp: error processing module "
 				"config parameters [module(...)]");
 		ABORT_FINALIZE(RS_RET_MISSING_CNFPARAMS);
 	}
@@ -1058,13 +1079,15 @@ CODESTARTsetModCnf
 		} else if(!strcmp(modpblk.descr[i].name, "threads")) {
 			wrkrMax = (int) pvals[i].val.d.n;
 			if(wrkrMax > MAX_WRKR_THREADS) {
-				errmsg.LogError(0, RS_RET_PARAM_ERROR, "imudp: configured for %d"
+				LogError(0, RS_RET_PARAM_ERROR, "imudp: configured for %d"
 						"worker threads, but maximum permitted is %d",
 						wrkrMax, MAX_WRKR_THREADS);
 				loadModConf->wrkrMax = MAX_WRKR_THREADS;
 			} else {
 				loadModConf->wrkrMax = wrkrMax;
 			}
+		} else if(!strcmp(modpblk.descr[i].name, "preservecase")) {
+			loadModConf->bPreserveCase = (int) pvals[i].val.d.n;
 		} else {
 			dbgprintf("imudp: program error, non-handled "
 			  "param '%s' in beginCnfLoad\n", modpblk.descr[i].name);
@@ -1111,7 +1134,7 @@ CODESTARTcheckCnf
 		std_checkRuleset(pModConf, inst);
 	}
 	if(pModConf->root == NULL) {
-		errmsg.LogError(0, RS_RET_NO_LISTNERS , "imudp: module loaded, but "
+		LogError(0, RS_RET_NO_LISTNERS , "imudp: module loaded, but "
 				"no listeners defined - no input will be gathered");
 		iRet = RS_RET_NO_LISTNERS;
 	}
@@ -1127,7 +1150,7 @@ CODESTARTactivateCnfPrePrivDrop
 	}
 	/* if we could not set up any listeners, there is no point in running... */
 	if(lcnfRoot == NULL) {
-		errmsg.LogError(0, NO_ERRCODE, "imudp: no listeners could be started, "
+		LogError(0, NO_ERRCODE, "imudp: no listeners could be started, "
 				"input not activated.\n");
 		ABORT_FINALIZE(RS_RET_NO_RUN);
 	}
@@ -1196,7 +1219,7 @@ wrkr(void *myself)
 
 	/* Note well: the setting of scheduling parameters will not work
 	 * when we dropped privileges (if the user is not sufficiently
-	 * privileged, of course). Howerver, we can't change the 
+	 * privileged, of course). Howerver, we can't change the
 	 * scheduling params in PrePrivDrop(), as at that point our thread
 	 * is not yet created. So at least as an interim solution, we do
 	 * NOT support both setting sched parameters and dropping
@@ -1293,7 +1316,6 @@ ENDafterRun
 BEGINmodExit
 CODESTARTmodExit
 	/* release what we no longer need */
-	objRelease(errmsg, CORE_COMPONENT);
 	objRelease(glbl, CORE_COMPONENT);
 	objRelease(statsobj, CORE_COMPONENT);
 	objRelease(datetime, CORE_COMPONENT);
@@ -1340,7 +1362,6 @@ BEGINmodInit()
 CODESTARTmodInit
 	*ipIFVersProvided = CURR_MOD_IF_VERSION; /* we only support the current interface specification */
 CODEmodInit_QueryRegCFSLineHdlr
-	CHKiRet(objUse(errmsg, CORE_COMPONENT));
 	CHKiRet(objUse(glbl, CORE_COMPONENT));
 	CHKiRet(objUse(statsobj, CORE_COMPONENT));
 	CHKiRet(objUse(datetime, CORE_COMPONENT));
