@@ -3,18 +3,18 @@
  *
  * File begun on 2017-03-03 by Pascal Withopf.
  *
- * Copyright 2014-2017 Adiscon GmbH.
+ * Copyright 2014-2018 Adiscon GmbH.
  *
  * This file is part of rsyslog.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *       http://www.apache.org/licenses/LICENSE-2.0
  *       -or-
  *       see COPYING.ASL20 in the source distribution
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -30,7 +30,6 @@
 #include <ctype.h>
 #include <liblognorm.h>
 #include <json.h>
-#include "syslogd.h"
 #include "conf.h"
 #include "syslogd-types.h"
 #include "template.h"
@@ -49,7 +48,6 @@ MODULE_CNFNAME("pmnormalize")
 
 /* internal structures */
 DEF_PMOD_STATIC_DATA
-DEFobjCurrIf(errmsg)
 DEFobjCurrIf(glbl)
 DEFobjCurrIf(parser)
 DEFobjCurrIf(datetime)
@@ -83,7 +81,6 @@ CODESTARTisCompatibleWithFeature
 		iRet = RS_RET_OK;
 ENDisCompatibleWithFeature
 
-
 /* create input instance, set default parameters, and
  * add it to the list of instances.
  */
@@ -96,6 +93,7 @@ createInstance(instanceConf_t **pinst)
 	inst->undefPropErr = 0;
 	inst->rulebase = NULL;
 	inst->rule = NULL;
+	inst->ctxln = NULL;
 	*pinst = inst;
 finalize_it:
 	RETiRet;
@@ -106,7 +104,7 @@ static void
 errCallBack(void __attribute__((unused)) *cookie, const char *msg,
 	    size_t __attribute__((unused)) lenMsg)
 {
-	errmsg.LogError(0, RS_RET_ERR_LIBLOGNORM, "liblognorm error: %s", msg);
+	LogError(0, RS_RET_ERR_LIBLOGNORM, "liblognorm error: %s", msg);
 }
 
 /* to be called to build the liblognorm part of the instance ONCE ALL PARAMETERS ARE CORRECT
@@ -117,7 +115,7 @@ buildInstance(instanceConf_t *inst)
 {
 	DEFiRet;
 	if((inst->ctxln = ln_initCtx()) == NULL) {
-		errmsg.LogError(0, RS_RET_ERR_LIBLOGNORM_INIT, "error: could not initialize "
+		LogError(0, RS_RET_ERR_LIBLOGNORM_INIT, "error: could not initialize "
 				"liblognorm ctx, cannot activate action");
 		ABORT_FINALIZE(RS_RET_ERR_LIBLOGNORM_INIT);
 	}
@@ -125,7 +123,7 @@ buildInstance(instanceConf_t *inst)
 
 	if(inst->rule != NULL && inst->rulebase == NULL) {
 		if(ln_loadSamplesFromString(inst->ctxln, inst->rule) !=0) {
-			errmsg.LogError(0, RS_RET_NO_RULEBASE, "error: normalization rulebase '%s' "
+			LogError(0, RS_RET_NO_RULEBASE, "error: normalization rulebase '%s' "
 					"could not be loaded cannot activate action", inst->rulebase);
 			ln_exitCtx(inst->ctxln);
 			ABORT_FINALIZE(RS_RET_ERR_LIBLOGNORM_SAMPDB_LOAD);
@@ -134,7 +132,7 @@ buildInstance(instanceConf_t *inst)
 		inst->rule = NULL;
 	} else if(inst->rulebase != NULL && inst->rule == NULL) {
 		if(ln_loadSamples(inst->ctxln, (char*) inst->rulebase) != 0) {
-			errmsg.LogError(0, RS_RET_NO_RULEBASE, "error: normalization rulebase '%s' "
+			LogError(0, RS_RET_NO_RULEBASE, "error: normalization rulebase '%s' "
 					"could not be loaded cannot activate action", inst->rulebase);
 			ln_exitCtx(inst->ctxln);
 			ABORT_FINALIZE(RS_RET_ERR_LIBLOGNORM_SAMPDB_LOAD);
@@ -148,6 +146,9 @@ finalize_it:
 BEGINfreeParserInst
 CODESTARTfreeParserInst
 	dbgprintf("pmnormalize: free parser instance %p\n", pInst);
+	if(pInst->ctxln != NULL) {
+		ln_exitCtx(pInst->ctxln);
+	}
 ENDfreeParserInst
 
 
@@ -176,7 +177,7 @@ CODESTARTnewParserInst
 		if(!pvals[i].bUsed)
 			continue;
 		if(!strcmp(parserpblk.descr[i].name, "undefinedpropertyerror")) {
-			inst->undefPropErr = (int) pvals[i].val.d.n; 
+			inst->undefPropErr = (int) pvals[i].val.d.n;
 		} else if(!strcmp(parserpblk.descr[i].name, "rulebase")) {
 			inst->rulebase = (char *) es_str2cstr(pvals[i].val.d.estr, NULL);
 		} else if(!strcmp(parserpblk.descr[i].name, "rule")) {
@@ -187,18 +188,20 @@ CODESTARTnewParserInst
 				CHKiRet(es_addChar(&rules, '\n'));
 			}
 			inst->rule = (char*)es_str2cstr(rules, NULL);
+			if(rules != NULL)
+				es_deleteStr(rules);
 		} else {
-                        LogError(0, RS_RET_INTERNAL_ERROR ,
+			LogError(0, RS_RET_INTERNAL_ERROR ,
 				"pmnormalize: program error, non-handled param '%s'",
 				parserpblk.descr[i].name);
-                }
+		}
 	}
 	if(!inst->rulebase && !inst->rule) {
-		errmsg.LogError(0, RS_RET_CONFIG_ERROR, "pmnormalize: rulebase needed. "
+		LogError(0, RS_RET_CONFIG_ERROR, "pmnormalize: rulebase needed. "
 				"Use option rulebase or rule.");
 	}
 	if(inst->rulebase && inst->rule) {
-		errmsg.LogError(0, RS_RET_CONFIG_ERROR, "pmnormalize: only one rulebase "
+		LogError(0, RS_RET_CONFIG_ERROR, "pmnormalize: only one rulebase "
 				"possible, rulebase can't be used with rule");
 	}
 
@@ -227,7 +230,7 @@ CODESTARTparse2
 	if(r != 0) {
 		DBGPRINTF("error %d during ln_normalize\n", r);
 		if(pInst->undefPropErr) {
-			errmsg.LogError(0, RS_RET_ERR, "error %d during ln_normalize; "
+			LogError(0, RS_RET_ERR, "error %d during ln_normalize; "
 					"json: %s\n", r, fjson_object_to_json_string(json));
 		}
 	} else {
@@ -240,7 +243,6 @@ ENDparse2
 BEGINmodExit
 CODESTARTmodExit
 	/* release what we no longer need */
-	objRelease(errmsg, CORE_COMPONENT);
 	objRelease(glbl, CORE_COMPONENT);
 	objRelease(parser, CORE_COMPONENT);
 	objRelease(datetime, CORE_COMPONENT);
@@ -259,7 +261,6 @@ CODESTARTmodInit
 	*ipIFVersProvided = CURR_MOD_IF_VERSION; /* we only support the current interface specification */
 CODEmodInit_QueryRegCFSLineHdlr
 	CHKiRet(objUse(glbl, CORE_COMPONENT));
-	CHKiRet(objUse(errmsg, CORE_COMPONENT));
 	CHKiRet(objUse(parser, CORE_COMPONENT));
 	CHKiRet(objUse(datetime, CORE_COMPONENT));
 
