@@ -11,7 +11,7 @@
  *
  * File begun on 2007-07-22 by RGerhards
  *
- * Copyright 2007-2016 Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2007-2018 Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of the rsyslog runtime library.
  *
@@ -32,8 +32,6 @@
  * A copy of the LGPL can be found in the file "COPYING.LESSER" in this distribution.
  */
 #include "config.h"
-#include "rsyslog.h"
-#include "rainerscript.h"
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -55,6 +53,8 @@
 #	define PATH_MAX MAXPATHLEN
 #endif
 
+#include "rsyslog.h"
+#include "rainerscript.h"
 #include "cfsysline.h"
 #include "rsconf.h"
 #include "modules.h"
@@ -110,7 +110,7 @@ dummyIsCompatibleWithFeature(__attribute__((unused)) syslogFeature eFeat)
 }
 static rsRetVal
 dummynewActInst(uchar *modName, struct nvlst __attribute__((unused)) *dummy1,
-	  	void __attribute__((unused)) **dummy2, omodStringRequest_t __attribute__((unused)) **dummy3) 
+		void __attribute__((unused)) **dummy2, omodStringRequest_t __attribute__((unused)) **dummy3)
 {
 	LogError(0, RS_RET_CONFOBJ_UNSUPPORTED, "config objects are not "
 			"supported by module '%s' -- legacy config options "
@@ -373,7 +373,7 @@ readyModForCnf(modInfo_t *pThis, cfgmodules_etry_t **ppNew, cfgmodules_etry_t **
 	}
 
 	/* check for duplicates and, as a side-activity, identify last node */
-	pLast = loadConf->modules.root; 
+	pLast = loadConf->modules.root;
 	if(pLast != NULL) {
 		while(1) { /* loop broken inside */
 			if(pLast->pMod == pThis) {
@@ -461,7 +461,7 @@ finalize_it:
 /* Get the next module pointer - this is used to traverse the list.
  * The function returns the next pointer or NULL, if there is no next one.
  * The last object must be provided to the function. If NULL is provided,
- * it starts at the root of the list. Even in this case, NULL may be 
+ * it starts at the root of the list. Even in this case, NULL may be
  * returned - then, the list is empty.
  * rgerhards, 2007-07-23
  */
@@ -863,7 +863,7 @@ finalize_it:
 	RETiRet;
 }
 
-/* Print loaded modules. This is more or less a 
+/* Print loaded modules. This is more or less a
  * debug or test aid, but anyhow I think it's worth it...
  * This only works if the dbgprintf() subsystem is initialized.
  * TODO: update for new input modules!
@@ -1121,12 +1121,12 @@ findModule(uchar *pModName, int iModNameLen, modInfo_t **pMod)
  * of modules, but the current implementation at least looks simpler.
  * Note: pvals = NULL means legacy config system
  */
-static rsRetVal
-Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
+static rsRetVal ATTR_NONNULL(1)
+Load(uchar *const pModName, const sbool bConfLoad, struct nvlst *const lst)
 {
 	size_t iPathLen, iModNameLen;
 	int bHasExtension;
-        void *pModHdlr, *pModInit;
+	void *pModHdlr, *pModInit;
 	modInfo_t *pModInfo;
 	cfgmodules_etry_t *pNew = NULL;
 	cfgmodules_etry_t *pLast = NULL;
@@ -1141,6 +1141,7 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 	uchar *pPathBuf = pathBuf;
 	size_t lenPathBuf = sizeof(pathBuf);
 	rsRetVal localRet;
+	cstr_t *load_err_msg = NULL;
 	DEFiRet;
 
 	assert(pModName != NULL);
@@ -1173,7 +1174,7 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 						    pModName);
 						ABORT_FINALIZE(RS_RET_DUP_PARAM);
 					} else {
-						/* for built-in moules, we need to call setModConf, 
+						/* for built-in moules, we need to call setModConf,
 						 * because there is no way to set parameters at load
 						 * time for obvious reasons...
 						 */
@@ -1192,8 +1193,7 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 		FINALIZE;
 	}
 
-	pModDirCurr = (uchar *)((pModDir == NULL) ?
-		      _PATH_MODDIR : (char *)pModDir);
+	pModDirCurr = (uchar *)((pModDir == NULL) ? _PATH_MODDIR : (char *)pModDir);
 	pModDirNext = NULL;
 	pModHdlr    = NULL;
 	iLoadCnt    = 0;
@@ -1269,18 +1269,29 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 			pModHdlr = dlopen((char *) pPathBuf, RTLD_NOW);
 		}
 
+		if(pModHdlr == NULL) {
+			char errmsg[4096];
+			snprintf(errmsg, sizeof(errmsg), "%strying to load module %s: %s",
+				(load_err_msg == NULL) ? "" : "  ////////  ",
+				pPathBuf, dlerror());
+			if(load_err_msg == NULL) {
+				rsCStrConstructFromszStr(&load_err_msg, (uchar*)errmsg);
+			} else {
+				rsCStrAppendStr(load_err_msg, (uchar*)errmsg);
+			}
+		}
+
 		iLoadCnt++;
 	
 	} while(pModHdlr == NULL && *pModName != '/' && pModDirNext);
 
+	if(load_err_msg != NULL) {
+		cstrFinalize(load_err_msg);
+	}
+
 	if(!pModHdlr) {
-		if(iLoadCnt) {
-			LogError(0, RS_RET_MODULE_LOAD_ERR_DLOPEN, "could not load module '%s', dlopen: %s\n",
-					pPathBuf, dlerror());
-		} else {
-			LogError(0, NO_ERRCODE, "could not load module '%s', ModDir was '%s'\n", pPathBuf,
-			                               ((pModDir == NULL) ? _PATH_MODDIR : (char *)pModDir));
-		}
+		LogError(0, RS_RET_MODULE_LOAD_ERR_DLOPEN, "could not load module '%s', errors: %s", pModName,
+			(load_err_msg == NULL) ? "NONE SEEN???" : (const char*) cstrGetSzStrNoNULL(load_err_msg));
 		ABORT_FINALIZE(RS_RET_MODULE_LOAD_ERR_DLOPEN);
 	}
 	if(!(pModInit = dlsym(pModHdlr, "modInit"))) {
@@ -1289,15 +1300,10 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 		dlclose(pModHdlr);
 		ABORT_FINALIZE(RS_RET_MODULE_LOAD_ERR_NO_INIT);
 	}
-#ifdef _AIX
-/*  AIXPORT : typecaste address of pModInit  in AIX */
 	if((iRet = doModInit((rsRetVal(*)(int,int*,rsRetVal(**)(),rsRetVal(*)(),struct modInfo_s*))pModInit,
-(uchar*) pModName, pModHdlr, &pModInfo)) != RS_RET_OK) {
-#else
-	if((iRet = doModInit(pModInit, (uchar*) pModName, pModHdlr, &pModInfo)) != RS_RET_OK) {
-#endif
+		(uchar*) pModName, pModHdlr, &pModInfo)) != RS_RET_OK) {
 		LogError(0, RS_RET_MODULE_LOAD_ERR_INIT_FAILED,
-				"could not load module '%s', rsyslog error %d\n", pPathBuf, iRet);
+			"could not load module '%s', rsyslog error %d\n", pPathBuf, iRet);
 		dlclose(pModHdlr);
 		ABORT_FINALIZE(RS_RET_MODULE_LOAD_ERR_INIT_FAILED);
 	}
@@ -1320,6 +1326,9 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 	}
 
 finalize_it:
+	if(load_err_msg != NULL) {
+		cstrDestruct(&load_err_msg);
+	}
 	if(pPathBuf != pathBuf) /* used malloc()ed memory? */
 		free(pPathBuf);
 	if(iRet != RS_RET_OK)
@@ -1406,7 +1415,7 @@ Use(const char *srcFile, modInfo_t *pThis)
 
 
 /* Reference-Counting object access: subract one from the current refcount. Must
- * by called by anyone who no longer needs a module. If count reaches 0, the 
+ * by called by anyone who no longer needs a module. If count reaches 0, the
  * module is unloaded. -- rgerhards, 20080-03-10
  */
 static rsRetVal
