@@ -30,7 +30,31 @@
 #pragma GCC diagnostic ignored "-Wredundant-decls" // TODO: remove!
 #pragma GCC diagnostic ignored "-Wstrict-prototypes" // TODO: remove!
 #pragma GCC diagnostic ignored "-Wswitch-default" // TODO: remove!
-#endif
+#if __GNUC__ >= 8
+/* GCC, starting at least with version 8, is now really overdoing with it's
+ * warning messages. We turn those off that either cause an enormous amount
+ * of false positives or flag perfectly legal code as problematic.
+ */
+/* That one causes warnings when we use variable buffers for error
+ * messages which may be truncated in the very unlikely case of all
+ * vars using max value. If going over the max size, the engine will
+ * most likely truncate due to max message size anyhow. Also, sizing
+ * the buffers for max-max message size is a wast of (stack) memory.
+ */
+#pragma GCC diagnostic ignored "-Wformat-truncation"
+/* The next one flags variable initializations within out exception handling
+ * (iRet system) as problematic, even though variables are not used in those
+ * cases. This would be a good diagnostic if gcc would actually check that
+ * a variable is used uninitialized. Unfortunately it does not do that. But
+ * the static analyzers we use as part of CI do, so we are covered in any
+ * case.
+ * Unfortunately ignoring this diagnostic leads to two more info lines
+ * being emitted where nobody knows what the mean and why they appear :-(
+ */
+#pragma GCC diagnostic ignored "-Wjump-misses-init"
+#endif /* if __GNUC__ >= 8 */
+#endif /* ifndef AIX */
+
 #include <pthread.h>
 #include "typedefs.h"
 
@@ -109,6 +133,7 @@ extern int src_exists;
 /* make sure we uses consistent macros, no matter what the
  * platform gives us.
  */
+#undef LOG_NFACILITIES /* may be system defined, override */
 #define LOG_NFACILITIES 24+1 /* plus one for our special "invld" facility! */
 #define LOG_MAXPRI 191	/* highest supported valid PRI value --> RFC3164, RFC5424 */
 #undef LOG_MAKEPRI
