@@ -1,8 +1,8 @@
 #!/bin/bash
 . $srcdir/diag.sh init
 mysql --user=rsyslog --password=testbench < testsuites/mysql-truncate.sql
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 $ModLoad ../plugins/ommysql/.libs/ommysql
 global(errormessagestostderr.maxnumber="50")
 
@@ -20,13 +20,13 @@ if($msg contains "msgnum:") then {
 	action(type="ommysql" name="mysql_action" server="127.0.0.1" template="tpl"
 	       db="Syslog" uid="rsyslog" pwd="testbench")
 }
-action(type="omfile" file="rsyslog2.out.log")
+action(type="omfile" file=`echo $RSYSLOG2_OUT_LOG`)
 '
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh injectmsg 0 5000
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
+startup
+injectmsg 0 5000
+shutdown_when_empty
+wait_shutdown
 # note "-s" is requried to suppress the select "field header"
-mysql -s --user=rsyslog --password=testbench < testsuites/mysql-select-msg.sql > rsyslog.out.log
-. $srcdir/diag.sh seq-check  0 4999 -i2
-. $srcdir/diag.sh exit
+mysql -s --user=rsyslog --password=testbench < testsuites/mysql-select-msg.sql > $RSYSLOG_OUT_LOG
+seq_check  0 4999 -i2
+exit_test
