@@ -12,11 +12,23 @@ if [ `uname` = "SunOS" ] ; then
 fi
 
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup cee_diskqueue.conf
-. $srcdir/diag.sh injectmsg  0 5000
+generate_conf
+add_conf '
+global(workDirectory="/tmp")
+template(name="outfmt" type="string" string="%$!usr!msg:F,58:2%\n")
+
+set $!usr!msg = $msg;
+if $msg contains '
+add_conf "'msgnum' "
+add_conf 'then
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt"
+	       queue.type="disk" queue.filename="rsyslog-act1")
+'
+startup
+injectmsg  0 5000
 echo doing shutdown
-. $srcdir/diag.sh shutdown-when-empty
+shutdown_when_empty
 echo wait on shutdown
-. $srcdir/diag.sh wait-shutdown 
-. $srcdir/diag.sh seq-check  0 4999
-. $srcdir/diag.sh exit
+wait_shutdown 
+seq_check  0 4999
+exit_test
