@@ -8,22 +8,22 @@
 # hardcoded default of "localhost-empty-hostname" is used.
 # Note that the test may fail if the library is not properly preloaded.
 # This is part of the rsyslog testbench, licensed under ASL 2.0
-echo ======================================================================
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
-action(type="omfile" file="rsyslog.out.log")
+skip_platform "AIX" "we cannot preload required dummy lib"
+generate_conf
+add_conf '
+action(type="omfile" file=`echo $RSYSLOG_OUT_LOG`)
 '
 export RSYSLOG_PRELOAD=.libs/liboverride_gethostname.so
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown    # we need to wait until rsyslogd is finished!
+startup
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown    # we need to wait until rsyslogd is finished!
 
-grep " localhost-empty-hostname " < rsyslog.out.log
+grep " localhost-empty-hostname " < $RSYSLOG_OUT_LOG
 if [ ! $? -eq 0 ]; then
-  echo "expected hostname \"localhost-empty-hostname\" not found in logs, rsyslog.out.log is:"
-  cat rsyslog.out.log
-  . $srcdir/diag.sh error-exit 1
+  echo "expected hostname \"localhost-empty-hostname\" not found in logs, $RSYSLOG_OUT_LOG is:"
+  cat $RSYSLOG_OUT_LOG
+  error_exit 1
 fi;
 
-. $srcdir/diag.sh exit
+exit_test
