@@ -19,8 +19,8 @@ curl -H 'Content-Type: application/json' -XPUT localhost:19200/rsyslog_testbench
     }
   }
 }'
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 # Note: we must mess up with the template, because we can not
 # instruct ES to put further constraints on the data type and
 # values. So we require integer and make sure it is none.
@@ -35,16 +35,16 @@ module(load="../plugins/omelasticsearch/.libs/omelasticsearch")
 				 searchType="test-type"
 				 serverport="19200"
 				 bulkmode="off"
-				 errorFile="./rsyslog.errorfile")
+				 errorFile="./'${RSYSLOG_DYNNAME}'.errorfile")
 '
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh injectmsg  0 1000
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown 
-if [ ! -f rsyslog.errorfile ]
+startup
+injectmsg  0 1000
+shutdown_when_empty
+wait_shutdown 
+if [ ! -f ${RSYSLOG_DYNNAME}.errorfile ]
 then
     echo "error: error file does not exist!"
     exit 1
 fi
 . $srcdir/diag.sh cleanup-elasticsearch
-. $srcdir/diag.sh exit
+exit_test
