@@ -9,8 +9,8 @@ export ES_PORT=19200
 
 . $srcdir/diag.sh init
 . $srcdir/diag.sh es-init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="tpl" type="string"
 	 string="{\"msgnum\":\"%msg:F,58:2%\"}")
 
@@ -20,20 +20,20 @@ module(load="../plugins/omelasticsearch/.libs/omelasticsearch")
 				 serverport=`echo $ES_PORT`
 				 searchIndex="rsyslog_testbench"
 				 bulkmode="on"
-				 errorFile="./rsyslog.errorfile")
+				 errorFile="./'${RSYSLOG_DYNNAME}'.errorfile")
 '
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh injectmsg  0 10000
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown 
+startup
+injectmsg  0 10000
+shutdown_when_empty
+wait_shutdown 
 . $srcdir/diag.sh es-getdata 10000 $ES_PORT
-if [ -f rsyslog.errorfile ]
+if [ -f ${RSYSLOG_DYNNAME}.errorfile ]
 then
     echo "error: error file exists!"
-    cat rsyslog.errorfile
-    . $srcdir/diag.sh error-exit 1
+    cat ${RSYSLOG_DYNNAME}.errorfile
+    error_exit 1
 fi
-. $srcdir/diag.sh seq-check  0 9999 19200
+seq_check  0 9999 19200
 . $srcdir/diag.sh stop-elasticsearch
 . $srcdir/diag.sh cleanup-elasticsearch
-. $srcdir/diag.sh exit
+exit_test
