@@ -10,21 +10,32 @@
 echo ===============================================================================
 echo \[execonlyonce.sh\]: test for the $ActionExecOnlyOnceEveryInterval directive
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup execonlyonce.conf
-. $srcdir/diag.sh tcpflood -m10 -i1
+generate_conf
+add_conf '
+$ModLoad ../plugins/imtcp/.libs/imtcp
+$MainMsgQueueTimeoutShutdown 10000
+$InputTCPServerRun '$TCPFLOOD_PORT'
+
+$template outfmt,"%msg:F,58:2%\n"
+template(name="dynfile" type="string" string=`echo $RSYSLOG_OUT_LOG`) # trick to use relative path names!
+$ActionExecOnlyOnceEveryInterval 3
+:msg, contains, "msgnum:" ?dynfile;outfmt
+'
+startup
+tcpflood -m10 -i1
 # now wait until the interval definitely expires
 sleep 4 # one more than the once inerval!
 # and inject another couple of messages
-. $srcdir/diag.sh tcpflood -m10 -i100
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown
+tcpflood -m10 -i100
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown
 
 # now we need your custom logic to see if the result is equal to the
 # expected result
-cmp rsyslog.out.log testsuites/execonlyonce.data
+cmp $RSYSLOG_OUT_LOG testsuites/execonlyonce.data
 if [ $? -eq 1 ]
 then
 	echo "ERROR, output not as expected"
 	exit 1
 fi
-. $srcdir/diag.sh exit
+exit_test
