@@ -10,19 +10,28 @@ fi
 echo ===============================================================================
 echo \[failover-no-basic.sh\]: basic test for failover functionality - no failover
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup-vg failover-no-basic.conf
-. $srcdir/diag.sh injectmsg  0 5000
+generate_conf
+add_conf '
+$RepeatedMsgReduction off
+
+# second action should never execute
+:msg, contains, "msgnum:" /dev/null
+$ActionExecOnlyWhenPreviousIsSuspended on
+& ./'"${RSYSLOG_OUT_LOG}"'
+'
+startup_vg
+injectmsg  0 5000
 echo doing shutdown
-. $srcdir/diag.sh shutdown-when-empty
+shutdown_when_empty
 echo wait on shutdown
-. $srcdir/diag.sh wait-shutdown-vg
-. $srcdir/diag.sh check-exit-vg
+wait_shutdown_vg
+check_exit_vg
 # now we need our custom logic to see if the result file is empty
 # (what it should be!)
-cmp rsyslog.out.log /dev/null
+cmp $RSYSLOG_OUT_LOG /dev/null
 if [ $? -eq 1 ]
 then
 	echo "ERROR, output file not empty"
 	exit 1
 fi
-. $srcdir/diag.sh exit
+exit_test
