@@ -10,12 +10,22 @@ fi
 echo ===============================================================================
 echo \[failover-rptd.sh\]: rptd test for failover functionality
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup-vg failover-rptd.conf
-. $srcdir/diag.sh injectmsg  0 5000
+generate_conf
+add_conf '
+$RepeatedMsgReduction on
+
+$template outfmt,"%msg:F,58:2%\n"
+# note: the target server shall not be available!
+:msg, contains, "msgnum:" @@127.0.0.1:13514
+$ActionExecOnlyWhenPreviousIsSuspended on
+& ./'"${RSYSLOG_OUT_LOG}"';outfmt
+'
+startup_vg
+injectmsg  0 5000
 echo doing shutdown
-. $srcdir/diag.sh shutdown-when-empty
+shutdown_when_empty
 echo wait on shutdown
-. $srcdir/diag.sh wait-shutdown-vg
-. $srcdir/diag.sh check-exit-vg
-. $srcdir/diag.sh seq-check  0 4999
-. $srcdir/diag.sh exit
+wait_shutdown_vg
+check_exit_vg
+seq_check  0 4999
+exit_test
