@@ -6,11 +6,11 @@ echo ======================================================================
 echo [imfile-endregex-save-lf.sh]
 . $srcdir/diag.sh check-inotify
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 module(load="../plugins/imfile/.libs/imfile")
 input(type="imfile"
-      File="./rsyslog.input"
+      File="./'$RSYSLOG_DYNNAME'.input"
       Tag="file:"
       startmsg.regex="^[^ ]")
 template(name="outfmt" type="list") {
@@ -21,31 +21,31 @@ template(name="outfmt" type="list") {
 if $msg contains "msgnum:" then
  action(
    type="omfile"
-   file="rsyslog.out.log"
+   file=`echo $RSYSLOG_OUT_LOG`
    template="outfmt"
  )
 '
-. $srcdir/diag.sh startup
+startup
 
 # write the beginning of the file
 echo 'msgnum:0
  msgnum:1
- msgnum:2' > rsyslog.input
+ msgnum:2' > $RSYSLOG_DYNNAME.input
 # the next line terminates our test. It is NOT written to the output file,
 # as imfile waits whether or not there is a follow-up line that it needs
 # to combine.
-echo 'END OF TEST' >> rsyslog.input
+echo 'END OF TEST' >> $RSYSLOG_DYNNAME.input
 # sleep a little to give rsyslog a chance to begin processing
 ./msleep 500
 
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown    # we need to wait until rsyslogd is finished!
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown    # we need to wait until rsyslogd is finished!
 
-printf 'HEADER msgnum:0\\\\n msgnum:1\\\\n msgnum:2\n' | cmp - rsyslog.out.log
+printf 'HEADER msgnum:0\\\\n msgnum:1\\\\n msgnum:2\n' | cmp - $RSYSLOG_OUT_LOG
 if [ ! $? -eq 0 ]; then
-  echo "invalid multiline message generated, rsyslog.out.log is:"
-  cat rsyslog.out.log
+  echo "invalid multiline message generated, $RSYSLOG_OUT_LOG is:"
+  cat $RSYSLOG_OUT_LOG
   exit 1
 fi;
 
-. $srcdir/diag.sh exit
+exit_test
