@@ -1,17 +1,16 @@
 #!/bin/bash
 # added 2016-11-02 by rgerhards
 # This is part of the rsyslog testbench, licensed under ASL 2.0
-echo [imfile-persist-state-1.sh]
-. $srcdir/diag.sh check-inotify
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
-global(workDirectory="test-spool")
+. $srcdir/diag.sh check-inotify
+generate_conf
+add_conf '
+global(workDirectory="'${RSYSLOG_DYNNAME}'.spool")
 
 module(load="../plugins/imfile/.libs/imfile")
 
 input(	type="imfile"
-	file="./rsyslog.input"
+	file="./'$RSYSLOG_DYNNAME'.input"
 	tag="file:"
 	startmsg.regex="^msgnum"
 	PersistStateInterval="1"
@@ -19,13 +18,13 @@ input(	type="imfile"
 
 template(name="outfmt" type="string" string="%msg:F,58:2%\n")
 if $msg contains "msgnum:" then
-	action(type="omfile" file="rsyslog.out.log" template="outfmt")
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
 '
 # generate input file first. Note that rsyslog processes it as
 # soon as it start up (so the file should exist at that point).
-./inputfilegen 5 4000 > rsyslog.input
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown	# we need to wait until rsyslogd is finished!
-. $srcdir/diag.sh seq-check 0 3
-. $srcdir/diag.sh exit
+./inputfilegen 5 4000 > $RSYSLOG_DYNNAME.input
+startup
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown	# we need to wait until rsyslogd is finished!
+seq_check 0 3
+exit_test
