@@ -1,15 +1,36 @@
 #!/bin/bash
 # This is part of the rsyslog testbench, licensed under ASL 2.0
-echo ======================================================================
-echo [imfile-readmode2-with-persists-data-during-stop.sh]
 . $srcdir/diag.sh check-inotify
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup imfile-readmode2-with-persists-data-during-stop.conf
+generate_conf
+add_conf '
+global(workDirectory="'${RSYSLOG_DYNNAME}'.spool")
+module(load="../plugins/imfile/.libs/imfile")
+
+input(type="imfile"
+      File="./'$RSYSLOG_DYNNAME'.input"
+      Tag="file:"
+      ReadMode="2")
+
+template(name="outfmt" type="list") {
+  constant(value="HEADER ")
+  property(name="msg" format="json")
+  constant(value="\n")
+}
+
+if $msg contains "msgnum:" then
+ action(
+   type="omfile"
+   file=`echo $RSYSLOG_OUT_LOG`
+   template="outfmt"
+ )
+'
+startup
 
 # write the beginning of the file
 echo 'msgnum:0
- msgnum:1' > rsyslog.input
-echo 'msgnum:2' >> rsyslog.input
+ msgnum:1' > $RSYSLOG_DYNNAME.input
+echo 'msgnum:2' >> $RSYSLOG_DYNNAME.input
 
 # sleep a little to give rsyslog a chance to begin processing
 sleep 1
@@ -18,64 +39,64 @@ sleep 1
 # persisted and read again on startup. Results should still be
 # correct ;)
 echo stopping rsyslog
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
+shutdown_when_empty
+wait_shutdown
 
 # write some more lines - we want to check here if the initial
 # polling loop properly picks up that data. Note that even in
 # inotify case we do have one polling loop at startup, as this
 # is required to find data written while we were stopped.
-ls -l test-spool
+ls -l ${RSYSLOG_DYNNAME}.spool
 
 echo 'msgnum:3
- msgnum:4' >> rsyslog.input
+ msgnum:4' >> $RSYSLOG_DYNNAME.input
 
 echo restarting rsyslog
-. $srcdir/diag.sh startup imfile-readmode2-with-persists.conf
+startup
 echo restarted rsyslog, continuing with test
 
-echo ' msgnum:5' >> rsyslog.input
+echo ' msgnum:5' >> $RSYSLOG_DYNNAME.input
 echo 'msgnum:6
  msgnum:7
-msgnum:8' >> rsyslog.input
+msgnum:8' >> $RSYSLOG_DYNNAME.input
 #msgnum:8 must NOT be written as it is unfinished
 
 # give it time to finish
 sleep 1
 
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown    # we need to wait until rsyslogd is finished!
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown    # we need to wait until rsyslogd is finished!
 
 # give it time to write the output file
 sleep 1
 
 ## check if we have the correct number of messages
 
-NUMLINES=$(grep -c HEADER rsyslog.out.log 2>/dev/null)
+NUMLINES=$(grep -c HEADER  $RSYSLOG_OUT_LOG 2>/dev/null)
 
 if [ -z $NUMLINES ]; then
-  echo "ERROR: expecting at least a match for HEADER, maybe rsyslog.out.log wasn't even written?"
-  cat ./rsyslog.out.log
-  exit 1
+  echo "ERROR: expecting at least a match for HEADER, maybe  $RSYSLOG_OUT_LOG wasn't even written?"
+  cat $RSYSLOG_OUT_LOG
+  error_exit 1
 else
   if [ ! $NUMLINES -eq 4 ]; then
     echo "ERROR: expecting 4 headers, got $NUMLINES"
-    cat ./rsyslog.out.log
-    exit 1
+    cat $RSYSLOG_OUT_LOG
+    error_exit 1
   fi
 fi
 
 ## check if all the data we expect to get in the file is there
 
 for i in {1..7}; do
-  grep msgnum:$i rsyslog.out.log > /dev/null 2>&1
+  grep msgnum:$i  $RSYSLOG_OUT_LOG > /dev/null 2>&1
   if [ ! $? -eq 0 ]; then
     echo "ERROR: expecting the string 'msgnum:$i', it's not there"
-    cat ./rsyslog.out.log
-    exit 1
+    cat $RSYSLOG_OUT_LOG
+    error_exit 1
   fi
 done
 
 ## if we got here, all is good :)
 
-. $srcdir/diag.sh exit
+exit_test
