@@ -6,8 +6,15 @@
 # Copyright 2014 by Rainer Gerhards, licensed under ASL 2.0
 echo \[imudp_thread_hang\]: a situation where imudp caused a hang
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup imudp_thread_hang.conf
+generate_conf
+add_conf '
+$WorkDirectory '$RSYSLOG_DYNNAME'.spool
+
+module(load="../plugins/imudp/.libs/imudp" threads="3")
+input(type="imudp" Address="127.0.0.1" Port="20514")
+'
+startup
 ./msleep 1000
 . $srcdir/diag.sh shutdown-immediate
-. $srcdir/diag.sh wait-shutdown
-. $srcdir/diag.sh exit
+wait_shutdown
+exit_test
