@@ -7,16 +7,23 @@ if [ "$EUID" -ne 0 ]; then
     exit 77 # Not root, skip this test
 fi
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup imuxsock_logger_root.conf
+generate_conf
+add_conf '
+$ModLoad ../plugins/imuxsock/.libs/imuxsock
+
+$template outfmt,"%msg:%\n"
+*.notice      action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
+'
+startup
 # send a message with trailing LF
 logger test
 # the sleep below is needed to prevent too-early termination of rsyslogd
 ./msleep 100
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown	# we need to wait until rsyslogd is finished!
-cmp rsyslog.out.log $srcdir/resultdata/imuxsock_logger.log
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown	# we need to wait until rsyslogd is finished!
+cmp $RSYSLOG_OUT_LOG $srcdir/resultdata/imuxsock_logger.log
 if [ ! $? -eq 0 ]; then
 echo "imuxsock_logger.sh failed"
 exit 1
 fi;
-. $srcdir/diag.sh exit
+exit_test
