@@ -2,21 +2,21 @@
 # add 2016-11-22 by Jan Gerhards, released under ASL 2.0
 
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="outfmt" type="string" string="%msg%\n")
 
 module(load="../plugins/mmanon/.libs/mmanon")
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="13514" ruleset="testing")
+input(type="imtcp" port="'$TCPFLOOD_PORT'" ruleset="testing")
 
 ruleset(name="testing") {
 	action(type="mmanon" ipv4.enable="off" ipv6.enable="off" embeddedipv4.bits="128" embeddedipv4.anonmode="zero")
-	action(type="omfile" file="rsyslog.out.log" template="outfmt")
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
 }'
 
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh tcpflood -m1 -M "\"<129>Mar 10 01:00:00 172.20.245.8 tag: asdfghjk
+startup
+tcpflood -m1 -M "\"<129>Mar 10 01:00:00 172.20.245.8 tag: asdfghjk
 <129>Mar 10 01:00:00 172.20.245.8 tag: FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:255.255.255.255
 <129>Mar 10 01:00:00 172.20.245.8 tag: 61:34:ad::7:F aa:ff43::756:172.2.3.4
 <129>Mar 10 01:00:00 172.20.245.8 tag: ::
@@ -37,8 +37,8 @@ ruleset(name="testing") {
 <129>Mar 10 01:00:00 172.20.245.8 tag: 72:8374:adc7:47FF::43:172.1.1.0stillnoblank
 <129>Mar 10 01:00:00 172.20.245.8 tag: textnoblank72:8374:adc7:47FF::43:172.1.1.0stillnoblank\""
 
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
+shutdown_when_empty
+wait_shutdown
 echo ' asdfghjk
  0:0:0:0:0:0:0.0.0.0
  61:34:ad::7:F 0:0:0:0:0:0:0.0.0.0
@@ -58,11 +58,11 @@ echo ' asdfghjk
  12:12345::a.3.4.12.7
  textnoblank0:0:0:0:0:0:0.0.0.0
  0:0:0:0:0:0:0.0.0.0stillnoblank
- textnoblank0:0:0:0:0:0:0.0.0.0stillnoblank' | cmp - rsyslog.out.log
+ textnoblank0:0:0:0:0:0:0.0.0.0stillnoblank' | cmp - $RSYSLOG_OUT_LOG
 if [ ! $? -eq 0 ]; then
-  echo "invalid response generated, rsyslog.out.log is:"
-  cat rsyslog.out.log
-  . $srcdir/diag.sh error-exit  1
+  echo "invalid response generated, $RSYSLOG_OUT_LOG is:"
+  cat $RSYSLOG_OUT_LOG
+  error_exit  1
 fi;
 
-. $srcdir/diag.sh exit
+exit_test
