@@ -2,22 +2,22 @@
 # add 2016-11-22 by Jan Gerhards, released under ASL 2.0
 
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="outfmt" type="string" string="%msg%\n")
 
 module(load="../plugins/mmanon/.libs/mmanon")
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="13514" ruleset="testing")
+input(type="imtcp" port="'$TCPFLOOD_PORT'" ruleset="testing")
 
 ruleset(name="testing") {
 	action(type="mmanon" ipv4.bits="33" ipv4.mode="simple" ipv4.replacechar="*")
-	action(type="omfile" file="rsyslog.out.log" template="outfmt")
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
 }
-action(type="omfile" file="rsyslog2.out.log")'
+action(type="omfile" file=`echo $RSYSLOG2_OUT_LOG`)'
 
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh tcpflood -m1 -M "\"<129>Mar 10 01:00:00 172.20.245.8 tag: asdfghjk
+startup
+tcpflood -m1 -M "\"<129>Mar 10 01:00:00 172.20.245.8 tag: asdfghjk
 <129>Mar 10 01:00:00 172.20.245.8 tag: before 172.9.6.4
 <129>Mar 10 01:00:00 172.20.245.8 tag: 75.123.123.0 after
 <129>Mar 10 01:00:00 172.20.245.8 tag: before 181.23.1.4 after
@@ -44,8 +44,8 @@ action(type="omfile" file="rsyslog2.out.log")'
 <129>Mar 10 01:00:00 172.20.245.8 tag: 111.1.1.8.
 <129>Mar 10 01:00:00 172.20.245.8 tag: textnoblank1.1.31.9stillnoblank\""
 
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
+shutdown_when_empty
+wait_shutdown
 echo ' asdfghjk
  before ***.*.*.*
  **.***.***.* after
@@ -71,18 +71,18 @@ echo ' asdfghjk
  ****.*.*.*.1
  ***.*.*.*.1
  ***.*.*.*.
- textnoblank*.*.**.*stillnoblank' | cmp - rsyslog.out.log
+ textnoblank*.*.**.*stillnoblank' | cmp - $RSYSLOG_OUT_LOG
 if [ ! $? -eq 0 ]; then
-  echo "invalid response generated, rsyslog.out.log is:"
-  cat rsyslog.out.log
-  . $srcdir/diag.sh error-exit  1
+  echo "invalid response generated, $RSYSLOG_OUT_LOG is:"
+  cat $RSYSLOG_OUT_LOG
+  error_exit  1
 fi;
 
-grep 'invalid number of ipv4.bits (33), corrected to 32' rsyslog2.out.log > /dev/null
+grep 'invalid number of ipv4.bits (33), corrected to 32' ${RSYSLOG2_OUT_LOG} > /dev/null
 if [ $? -ne 0 ]; then
-  echo "invalid response generated, rsyslog2.out.log is:"
-  cat rsyslog2.out.log
-  . $srcdir/diag.sh error-exit  1
+  echo "invalid response generated, ${RSYSLOG2_OUT_LOG} is:"
+  cat ${RSYSLOG2_OUT_LOG}
+  error_exit  1
 fi;
 
-. $srcdir/diag.sh exit
+exit_test
