@@ -7,23 +7,23 @@ echo \[mmdb.sh\]: test for mmdb
 #export RSYSLOG_DEBUG="debug nostdout"
 #export RSYSLOG_DEBUGLOG="log"
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="outfmt" type="string" string="%$!iplocation%\n")
 
 module(load="../plugins/mmdblookup/.libs/mmdblookup")
 module(load="../plugins/mmnormalize/.libs/mmnormalize")
 module(load="../plugins/imptcp/.libs/imptcp")
-input(type="imptcp" port="13514" ruleset="testing")
+input(type="imptcp" port="'$TCPFLOOD_PORT'" ruleset="testing")
 
 ruleset(name="testing") {
-	action(type="mmnormalize" rulebase="./mmdb.rb")
-	action(type="mmdblookup" mmdbfile="./test.mmdb" key="$!ip" fields="city" )
-	action(type="omfile" file="./rsyslog.out.log" template="outfmt")
+	action(type="mmnormalize" rulebase=`echo $srcdir/mmdb.rb`)
+	action(type="mmdblookup" mmdbfile=`echo $srcdir/test.mmdb` key="$!ip" fields="city" )
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
 }'
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh tcpflood -m 1 -j "202.106.0.20\ "
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
-. $srcdir/diag.sh content-check '{ "city": "Beijing" }'
-. $srcdir/diag.sh exit 
+startup
+tcpflood -m 1 -j "202.106.0.20\ "
+shutdown_when_empty
+wait_shutdown
+content_check '{ "city": "Beijing" }'
+exit_test 
