@@ -1,23 +1,23 @@
 #!/bin/bash
 # add 2018-04-16 by Pascal Withopf, released under ASL 2.0
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="outfmt" type="string" string="%$!cim!msgnum%\n")
 
 module(load="../plugins/mmjsonparse/.libs/mmjsonparse")
 module(load="../plugins/imptcp/.libs/imptcp")
-input(type="imptcp" port="13514")
+input(type="imptcp" port="'$TCPFLOOD_PORT'")
 
 action(type="mmjsonparse" cookie="@cim:" container="$!cim")
 if $parsesuccess == "OK" then {
-	action(type="omfile" file="./rsyslog.out.log" template="outfmt")
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
 }
 '
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh tcpflood -m 5000 -j "@cim: "
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
-. $srcdir/diag.sh seq-check  0 4999
-. $srcdir/diag.sh exit
+startup
+tcpflood -m 5000 -j "@cim: "
+shutdown_when_empty
+wait_shutdown
+seq_check  0 4999
+exit_test
 
