@@ -2,16 +2,16 @@
 # addd 2017-10-18 by RGerhards, released under ASL 2.0
 
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 module(load="../plugins/omtesting/.libs/omtesting")
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="13514")
+input(type="imtcp" port="'$TCPFLOOD_PORT'")
 
 template(name="outfmt" type="string" string="%msg:F,58:2%\n")
 
 ruleset(name="rs3" queue.type="linkedList") {
-	action(type="omfile" template="outfmt" file="rsyslog.out.log")
+	action(type="omfile" template="outfmt" file=`echo $RSYSLOG_OUT_LOG`)
 }
 
 ruleset(name="rs2" queue.type="linkedList") {
@@ -25,12 +25,11 @@ ruleset(name="rs1" queue.type="linkedList") {
 
 if $msg contains "msgnum:" then call rs1
 '
-. $srcdir/diag.sh startup
-#. $srcdir/diag.sh tcpflood -p13514 -m10000
-. $srcdir/diag.sh injectmsg 0 1000
-#. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
+startup
+#tcpflood -p'$TCPFLOOD_PORT' -m10000
+injectmsg 0 1000
 . $srcdir/diag.sh shutdown-immediate
-. $srcdir/diag.sh wait-shutdown
+wait_shutdown
 # wo do not check reception - the main point is that we do not abort. The actual
 # message count is unknown (as the point is to shut down while still in processing).
-. $srcdir/diag.sh exit
+exit_test
