@@ -6,14 +6,33 @@
 # it has failed to process.
 
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup omprog-feedback.conf
-. $srcdir/diag.sh wait-startup
-. $srcdir/diag.sh injectmsg 0 10
-. $srcdir/diag.sh wait-queueempty
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
+generate_conf
+add_conf '
+module(load="../plugins/omprog/.libs/omprog")
 
-expected_output="<= OK
+template(name="outfmt" type="string" string="%msg%\n")
+
+:msg, contains, "msgnum:" {
+    action(
+        type="omprog"
+        binary=`echo $srcdir/testsuites/omprog-feedback-bin.sh`
+        template="outfmt"
+        name="omprog_action"
+        queue.type="Direct"  # the default; facilitates sync with the child process
+        confirmMessages="on"
+        reportFailures="on"
+        action.resumeInterval="1"  # retry interval: 1 second
+#       action.resumeRetryCount="0" # the default; no need to increase since
+                                    # the action resumes immediately
+    )
+}
+'
+startup
+injectmsg 0 10
+shutdown_when_empty
+wait_shutdown
+
+EXPECTED="<= OK
 => msgnum:00000000:
 <= OK
 => msgnum:00000001:
@@ -43,11 +62,6 @@ expected_output="<= OK
 => msgnum:00000009:
 <= OK"
 
-written_output=$(<rsyslog.out.log)
-if [[ "$expected_output" != "$written_output" ]]; then
-    echo unexpected omprog script output:
-    echo "$written_output"
-    . $srcdir/diag.sh error-exit 1
-fi
+cmp_exact $RSYSLOG_OUT_LOG
 
-. $srcdir/diag.sh exit
+exit_test
