@@ -5,8 +5,8 @@
 
 psql -h localhost -U postgres -f testsuites/pgsql-basic.sql
 
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="pgtemplate" type="list" option.sql="on") {
 	constant(value="INSERT INTO SystemEvents (SysLogTag) values ('"'"'")
 	property(name="msg")
@@ -20,19 +20,19 @@ if $msg contains "msgnum" then {
 		template="pgtemplate")
 }'
 
-. $srcdir/diag.sh startup-vg
-. $srcdir/diag.sh injectmsg  0 5000
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown-vg
-. $srcdir/diag.sh check-exit-vg
+startup_vg
+injectmsg  0 5000
+shutdown_when_empty
+wait_shutdown_vg
+check_exit_vg
 
 # we actually put the message in the SysLogTag field, so we know it doesn't use the default
 # template, like in pgsql-basic
-psql -h localhost -U postgres -d syslogtest -f testsuites/pgsql-select-syslogtag.sql -t -A > rsyslog.out.log
+psql -h localhost -U postgres -d syslogtest -f testsuites/pgsql-select-syslogtag.sql -t -A > $RSYSLOG_OUT_LOG
 
-. $srcdir/diag.sh seq-check  0 4999
+seq_check  0 4999
 
 echo cleaning up test database
 psql -h localhost -U postgres -c 'DROP DATABASE IF EXISTS syslogtest;'
 
-. $srcdir/diag.sh exit
+exit_test
