@@ -1,12 +1,12 @@
 #!/bin/bash
-# This file is part of the rsyslog project, released under GPLv3
+# This file is part of the rsyslog project, released under ASL 2.0
 
 . $srcdir/diag.sh init
 
-psql -h localhost -U postgres -f testsuites/pgsql-basic.sql
+psql -h localhost -U postgres -f ${srcdir}/testsuites/pgsql-basic.sql
 
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="pgtemplate" type="list" option.sql="on") {
 	constant(value="INSERT INTO SystemEvents (SysLogTag) values ('"'"'")
 	property(name="msg")
@@ -20,17 +20,18 @@ if $msg contains "msgnum" then {
 		template="pgtemplate")
 }'
 
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh injectmsg  0 5000
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
+startup
+injectmsg  0 5000
+shutdown_when_empty
+wait_shutdown
 
 
-psql -h localhost -U postgres -d syslogtest -f testsuites/pgsql-select-syslogtag.sql -t -A > rsyslog.out.log 
+psql -h localhost -U postgres -d syslogtest -f ${srcdir}/testsuites/pgsql-select-syslogtag.sql -t -A > $RSYSLOG_OUT_LOG 
 
-. $srcdir/diag.sh seq-check  0 4999
+
+seq_check  0 4999
 
 echo cleaning up test database
 psql -h localhost -U postgres -c 'DROP DATABASE IF EXISTS syslogtest;'
 
-. $srcdir/diag.sh exit
+exit_test
