@@ -8,23 +8,42 @@
 # uncomment for debugging support:
 echo testing memory queue persisting to disk, mode $1
 . $srcdir/diag.sh init
+generate_conf
+add_conf '
+$ModLoad ../plugins/imtcp/.libs/imtcp
+$MainMsgQueueTimeoutShutdown 1
+$MainMsgQueueSaveOnShutdown on
+$InputTCPServerRun '$TCPFLOOD_PORT'
 
+$ModLoad ../plugins/omtesting/.libs/omtesting
+
+# set spool locations and switch queue to disk-only mode
+$WorkDirectory '$RSYSLOG_DYNNAME'.spool
+$MainMsgQueueFilename mainq
+$IncludeConfig '${RSYSLOG_DYNNAME}'work-queuemode.conf
+
+$template outfmt,"%msg:F,58:2%\n"
+template(name="dynfile" type="string" string=`echo $RSYSLOG_OUT_LOG`) # trick to use relative path names!
+:msg, contains, "msgnum:" ?dynfile;outfmt
+
+$IncludeConfig '${RSYSLOG_DYNNAME}'work-delay.conf
+'
 # prepare config
-echo \$MainMsgQueueType $1 > work-queuemode.conf
-echo "*.*     :omtesting:sleep 0 1000" > work-delay.conf
+echo \$MainMsgQueueType $1 > ${RSYSLOG_DYNNAME}work-queuemode.conf
+echo "*.*     :omtesting:sleep 0 1000" > ${RSYSLOG_DYNNAME}work-delay.conf
 
 # inject 5000 msgs, so that we do not hit the high watermark
-. $srcdir/diag.sh startup queue-persist.conf
-. $srcdir/diag.sh injectmsg 0 5000
+startup
+injectmsg 0 5000
 . $srcdir/diag.sh shutdown-immediate
-. $srcdir/diag.sh wait-shutdown
+wait_shutdown
 . $srcdir/diag.sh check-mainq-spool
 
 # restart engine and have rest processed
 #remove delay
-echo "#" > work-delay.conf
-. $srcdir/diag.sh startup queue-persist.conf
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
+echo "#" > ${RSYSLOG_DYNNAME}work-delay.conf
+startup
+shutdown_when_empty # shut down rsyslogd when done processing messages
 ./msleep 1000
 $srcdir/diag.sh wait-shutdown
 # note: we need to permit duplicate messages, as due to the forced
@@ -32,5 +51,5 @@ $srcdir/diag.sh wait-shutdown
 # actually were processed. This is inline with rsyslog's philosophy
 # to better duplicate than loose messages. Duplicate messages are
 # permitted by the -d seq-check option.
-. $srcdir/diag.sh seq-check 0 4999 -d
-. $srcdir/diag.sh exit
+seq_check 0 4999 -d
+exit_test
