@@ -5,20 +5,20 @@
 # added 2018-01-22 by Rainer Gerhards; Released under ASL 2.0
 . $srcdir/diag.sh init
 export DO_STOP=on
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 template(name="outfmt" type="string" string="%msg:F,58:2%\n")
 
 if $msg contains "msgnum:" then {
 	if $msg contains "msgnum:00000000" then {
 		include(text="stop" config.enabled=`echo $DO_STOP`)
 	}
-	action(type="omfile" template="outfmt" file="rsyslog.out.log")
+	action(type="omfile" template="outfmt" file=`echo $RSYSLOG_OUT_LOG`)
 }
 '
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh injectmsg 0 10
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
-. $srcdir/diag.sh seq-check 1 9
-. $srcdir/diag.sh exit
+startup
+injectmsg 0 10
+shutdown_when_empty
+wait_shutdown
+seq_check 1 9
+exit_test
