@@ -11,12 +11,24 @@ fi
 echo ===============================================================================
 echo \[rscript_field-vg.sh\]: testing rainerscript field\(\) function
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup-vg rscript_field.conf
-. $srcdir/diag.sh injectmsg  0 5000
+generate_conf
+add_conf '
+template(name="outfmt" type="list") {
+	property(name="$!usr!msgnum")
+	constant(value="\n")
+}
+
+if $msg contains "msgnum" then {
+	set $!usr!msgnum = field($msg, 58, 2);
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
+}
+'
+startup_vg
+injectmsg  0 5000
 echo doing shutdown
-. $srcdir/diag.sh shutdown-when-empty
+shutdown_when_empty
 echo wait on shutdown
-. $srcdir/diag.sh wait-shutdown-vg
-. $srcdir/diag.sh check-exit-vg
-. $srcdir/diag.sh seq-check  0 4999
-. $srcdir/diag.sh exit
+wait_shutdown_vg
+check_exit_vg
+seq_check  0 4999
+exit_test
