@@ -1,15 +1,15 @@
 #!/bin/bash
 # Added 2017-12-09 by Rainer Gerhards, released under ASL 2.0
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 module(load="../plugins/imtcp/.libs/imtcp")
 module(load="../plugins/omtesting/.libs/omtesting")
-input(type="imtcp" port="13514")
+input(type="imtcp" port="'$TCPFLOOD_PORT'")
 template(name="outfmt" type="string" string="%msg:F,58:2%\n")
 
 ruleset(name="output_writer") {
-	action(type="omfile" file="rsyslog.out.log" template="outfmt")
+	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
 }
 
 :msg, contains, "msgnum:" {
@@ -19,9 +19,9 @@ ruleset(name="output_writer") {
 }
 '
 
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh injectmsg 0 10
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
-. $srcdir/diag.sh seq-check 1 9
-. $srcdir/diag.sh exit
+startup
+injectmsg 0 10
+shutdown_when_empty
+wait_shutdown
+seq_check 1 9
+exit_test
