@@ -4,11 +4,22 @@
 echo ===============================================================================
 echo \[rscript_random.sh\]: test for random-number-generator script-function
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup rscript_random.conf
-. $srcdir/diag.sh tcpflood -m 20
+generate_conf
+add_conf '
+template(name="outfmt" type="string" string="%$.random_no%\n")
+
+module(load="../plugins/imtcp/.libs/imtcp")
+input(type="imtcp" port="'$TCPFLOOD_PORT'")
+
+set $.random_no = random(10);
+
+action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
+'
+startup
+tcpflood -m 20
 echo doing shutdown
-. $srcdir/diag.sh shutdown-when-empty
+shutdown_when_empty
 echo wait on shutdown
-. $srcdir/diag.sh wait-shutdown 
+wait_shutdown 
 . $srcdir/diag.sh content-pattern-check "^[0-9]$"
-. $srcdir/diag.sh exit
+exit_test
