@@ -1,23 +1,30 @@
 #!/bin/bash
 # This test tests tcp forwarding with assigned template. To do so, a simple
 # tcp listener service is started.
-# added 2012-10-30 by Rgerhards. Released under GNU GPLv3+
-echo ===============================================================================
-echo \[tcp_forwarding_tpl.sh\]: test for tcp forwarding with assigned template
+# added 2012-10-30 by Rgerhards. Released under ASL 2.0
 
 # create the pipe and start a background process that copies data from 
 # it to the "regular" work file
 . $srcdir/diag.sh init
-./minitcpsrv 127.0.0.1 13514 rsyslog.out.log &
+generate_conf
+add_conf '
+$MainMsgQueueTimeoutShutdown 10000
+template(name="outfmt" type="string" string="%msg:F,58:2%\n")
+
+if $msg contains "msgnum:" then
+	action(type="omfwd" template="outfmt"
+	       target="127.0.0.1" port="'$TCPFLOOD_PORT'" protocol="tcp")
+'
+./minitcpsrv -t127.0.0.1 -p$TCPFLOOD_PORT -f $RSYSLOG_OUT_LOG &
 BGPROCESS=$!
 echo background minitcpsrvr process id is $BGPROCESS
 
 # now do the usual run
-. $srcdir/diag.sh startup tcp_forwarding_tpl.conf
+startup
 # 10000 messages should be enough
-. $srcdir/diag.sh injectmsg 0 10000
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown
+injectmsg 0 10000
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown
 
 # note: minitcpsrvr shuts down automatically if the connection is closed!
 # (we still leave the code here in in case we need it later)
@@ -27,5 +34,5 @@ echo background minitcpsrvr process id is $BGPROCESS
 #echo background process has terminated, continue test...
 
 # and continue the usual checks
-. $srcdir/diag.sh seq-check 0 9999
-. $srcdir/diag.sh exit
+seq_check 0 9999
+exit_test
