@@ -1,3 +1,4 @@
+#!/bin/bash
 # test many concurrent tcp connections
 # we send 100,000 messages in the hopes that his puts at least a little bit
 # of pressure on the threading subsystem. To really prove it, we would need to
@@ -7,13 +8,28 @@
 # should be covered by this test here.
 # rgerhards, 2009-06-26
 echo \[threadingmq.sh\]: main queue concurrency
-source $srcdir/diag.sh init
-source $srcdir/diag.sh startup threadingmq.conf
-source $srcdir/diag.sh injectmsg 0 100000
-source $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
+. $srcdir/diag.sh init
+generate_conf
+add_conf '
+$MainMsgQueueTimeoutShutdown 1
+#$MainMsgQueueTimeoutShutdown 100000
+
+$MainMsgQueueWorkerThreadMinimumMessages 10
+$MainMsgQueueWorkerThreads 5
+
+$template outfmt,"%msg:F,58:2%\n"
+template(name="dynfile" type="string" string=`echo $RSYSLOG_OUT_LOG`) # trick to use relative path names!
+# write quickly to the output file:
+$OMFileFlushOnTXEnd off
+$OMFileIOBufferSize 256k 
+:msg, contains, "msgnum:" ?dynfile;outfmt
+'
+startup
+injectmsg 0 100000
+shutdown_when_empty # shut down rsyslogd when done processing messages
 # we give an extra seconds for things to settle, especially
 # important on slower test machines
 ./msleep 5000
-source $srcdir/diag.sh wait-shutdown
-source $srcdir/diag.sh seq-check 0 99999
-source $srcdir/diag.sh exit
+wait_shutdown
+seq_check 0 99999
+exit_test
