@@ -13,30 +13,30 @@
 
 export TZ=TEST+02:00
 
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="13514")
+input(type="imtcp" port="'$TCPFLOOD_PORT'")
 
 template(name="outfmt" type="list") {
 	property(name="timegenerated" date.inUTC="on")
 	constant(value="\n")
 }
 :msg, contains, "msgnum:" action(type="omfile" template="outfmt"
-			         file="rsyslog.out.log")
+			         file=`echo $RSYSLOG_OUT_LOG`)
 '
 
 echo "***SUBTEST: check 2016-03-01"
-rm -f rsyslog.out.log	# do cleanup of previous subtest
-FAKETIME='2016-03-01 12:00:00' $srcdir/diag.sh startup
-. $srcdir/diag.sh tcpflood -m1
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
-echo "Mar  1 14:00:00" | cmp - rsyslog.out.log
+rm -f $RSYSLOG_OUT_LOG	# do cleanup of previous subtest
+FAKETIME='2016-03-01 12:00:00' startup
+tcpflood -m1
+shutdown_when_empty
+wait_shutdown
+echo "Mar  1 14:00:00" | cmp - $RSYSLOG_OUT_LOG
 if [ ! $? -eq 0 ]; then
-  echo "invalid timestamps generated, rsyslog.out.log is:"
-  cat rsyslog.out.log
+  echo "invalid timestamps generated, $RSYSLOG_OUT_LOG is:"
+  cat $RSYSLOG_OUT_LOG
   exit 1
 fi;
 
-. $srcdir/diag.sh exit
+exit_test
