@@ -9,28 +9,28 @@ echo \[timegenerated-ymd\]: check customized format \(Y-m-d\)
 
 export TZ=TEST-02:00
 
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 $ModLoad ../plugins/imtcp/.libs/imtcp
-$InputTCPServerRun 13514
+$InputTCPServerRun '$TCPFLOOD_PORT'
 
 template(name="outfmt" type="string"
 	 string="%timegenerated:::date-year%-%timegenerated:::date-month%-%timegenerated:::date-day%\n")
 :msg, contains, "msgnum:" action(type="omfile" template="outfmt"
-			         file="rsyslog.out.log")
+			         file=`echo $RSYSLOG_OUT_LOG`)
 '
-FAKETIME='2016-01-01 01:00:00' $srcdir/diag.sh startup
+FAKETIME='2016-01-01 01:00:00' startup
 # what we send actually is irrelevant, as we just use system properties.
 # but we need to send one message in order to gain output!
-. $srcdir/diag.sh tcpflood -m1
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
-echo "2016-01-01" | cmp - rsyslog.out.log
+tcpflood -m1
+shutdown_when_empty
+wait_shutdown
+echo "2016-01-01" | cmp - $RSYSLOG_OUT_LOG
 if [ ! $? -eq 0 ]; then
-  echo "invalid timestamps generated, rsyslog.out.log is:"
-  cat rsyslog.out.log
+  echo "invalid timestamps generated, $RSYSLOG_OUT_LOG is:"
+  cat $RSYSLOG_OUT_LOG
   exit 1
 fi;
 
 
-. $srcdir/diag.sh exit
+exit_test
