@@ -12,15 +12,24 @@ fi
 echo ===============================================================================
 echo \[udp-msgreduc-orgmsg-vg.sh\]: testing msg reduction via udp, with org message
 . $srcdir/diag.sh init
-. $srcdir/diag.sh startup-vg udp-msgreduc-orgmsg-vg.conf
-. $srcdir/diag.sh wait-startup
-. $srcdir/diag.sh tcpflood -t 127.0.0.1 -m 4 -r -Tudp -M "\"<133>2011-03-01T11:22:12Z host tag msgh ...\""
-. $srcdir/diag.sh tcpflood -t 127.0.0.1 -m 1 -r -Tudp -M "\"<133>2011-03-01T11:22:12Z host tag msgh ...x\""
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown-vg
+generate_conf
+add_conf '
+$ModLoad ../plugins/imudp/.libs/imudp
+$UDPServerRun '$TCPFLOOD_PORT'
+$RepeatedMsgReduction on
+$RepeatedMsgContainsOriginalMsg on
+
+$template outfmt,"%msg:F,58:2%\n"
+*.*       action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
+'
+startup_vg
+tcpflood -t 127.0.0.1 -m 4 -r -Tudp -M "\"<133>2011-03-01T11:22:12Z host tag msgh ...\""
+tcpflood -t 127.0.0.1 -m 1 -r -Tudp -M "\"<133>2011-03-01T11:22:12Z host tag msgh ...x\""
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown_vg
 if [ "$RSYSLOGD_EXIT" -eq "10" ]
 then
 	echo "udp-msgreduc-orgmsg-vg.sh FAILED"
 	exit 1
 fi
-. $srcdir/diag.sh exit
+exit_test
