@@ -3,6 +3,7 @@
 # all data to an output file, then a rsyslog instance is started which generates
 # messages and sends them to the unix socket. Datagram sockets are being used.
 # added 2010-08-06 by Rgerhards
+. $srcdir/diag.sh init
 
 uname
 if [ `uname` = "FreeBSD" ] ; then
@@ -10,22 +11,27 @@ if [ `uname` = "FreeBSD" ] ; then
    exit 77
 fi
 
-echo ===============================================================================
-echo \[uxsock_simple.sh\]: simple tests for omuxsock functionality
-
 # create the pipe and start a background process that copies data from 
 # it to the "regular" work file
-. $srcdir/diag.sh init
-./uxsockrcvr -srsyslog-testbench-dgram-uxsock -orsyslog.out.log &
+generate_conf
+add_conf '
+$MainMsgQueueTimeoutShutdown 10000
+
+$ModLoad ../plugins/omuxsock/.libs/omuxsock
+$template outfmt,"%msg:F,58:2%\n"
+$OMUXSockSocket '$RSYSLOG_DYNNAME'-testbench-dgram-uxsock
+:msg, contains, "msgnum:" :omuxsock:;outfmt
+'
+./uxsockrcvr -s$RSYSLOG_DYNNAME-testbench-dgram-uxsock -o $RSYSLOG_OUT_LOG -t 60 &
 BGPROCESS=$!
 echo background uxsockrcvr process id is $BGPROCESS
 
 # now do the usual run
-. $srcdir/diag.sh startup uxsock_simple.conf
+startup
 # 10000 messages should be enough
-. $srcdir/diag.sh injectmsg 0 10000
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown
+injectmsg 0 10000
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown
 
 # wait for the cp process to finish, do pipe-specific cleanup
 echo shutting down uxsockrcvr...
@@ -35,5 +41,5 @@ wait $BGPROCESS
 echo background process has terminated, continue test...
 
 # and continue the usual checks
-. $srcdir/diag.sh seq-check 0 9999
-. $srcdir/diag.sh exit
+seq_check 0 9999
+exit_test
