@@ -1,14 +1,14 @@
 #!/bin/bash
 # add 2018-04-19 by Pascal Withopf, released under ASL 2.0
 . $srcdir/diag.sh init
-. $srcdir/diag.sh generate-conf
-. $srcdir/diag.sh add-conf '
+generate_conf
+add_conf '
 $AbortOnUncleanConfig on
 $LocalHostName wtpshutdownall
 $PreserveFQDN on
 
 global(
-	workDirectory="test-spool"
+	workDirectory="'${RSYSLOG_DYNNAME}'.spool"
 )
 
 module(load="../plugins/mmjsonparse/.libs/mmjsonparse")
@@ -16,14 +16,14 @@ module(load="../plugins/impstats/.libs/impstats" interval="300"
 	resetCounters="on" format="cee" ruleset="metrics-impstat" log.syslog="on")
 
 ruleset(name="metrics-impstat" queue.type="Direct"){
-	action(type="omfile" file="test-spool/stats.log")
+	action(type="omfile" file="'$RSYSLOG_DYNNAME'.spool/stats.log")
 }
 '
-. $srcdir/diag.sh startup
-. $srcdir/diag.sh shutdown-when-empty
-. $srcdir/diag.sh wait-shutdown
+startup
+shutdown_when_empty
+wait_shutdown
 
 # This test only checks that rsyslog does not abort
 # so we don't need to check for output.
 
-. $srcdir/diag.sh exit
+exit_test
