@@ -22,7 +22,6 @@
  * limitations under the License.
  */
 #include "config.h"
-#include "rsyslog.h"
 
 #include <signal.h>
 #include <stdlib.h>
@@ -30,7 +29,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #include <errno.h>
-#ifdef HAVE_LIBLOGGING_STDLOG
+#ifdef ENABLE_LIBLOGGING_STDLOG
 #  include <liblogging/stdlog.h>
 #else
 #  include <syslog.h>
@@ -39,6 +38,7 @@
 #	include <systemd/sd-daemon.h>
 #endif
 
+#include "rsyslog.h"
 #include "wti.h"
 #include "ratelimit.h"
 #include "parser.h"
@@ -61,6 +61,17 @@
 #include "dirty.h"
 #include "janitor.h"
 
+/* some global vars we need to differentiate between environments,
+ * for TZ-related things see
+ * https://github.com/rsyslog/rsyslog/issues/2994
+ */
+static int runningInContainer = 0;
+#ifdef OS_LINUX
+static int emitTZWarning = 0;
+#else
+static int emitTZWarning = 1;
+#endif
+
 #if defined(_AIX)
 /* AIXPORT : start
  * The following includes and declarations are for support of the System
@@ -153,7 +164,7 @@ static int bHadHUP;
 static int doFork = 1; 	/* fork - run in daemon mode - read-only after startup */
 int bFinished = 0;	/* used by termination signal handler, read-only except there
 			 * is either 0 or the number of the signal that requested the
- 			 * termination.
+			 * termination.
 			 */
 const char *PidFile;
 #define NO_PIDFILE "NONE"
@@ -163,7 +174,7 @@ int MarkInterval = 20 * 60;	/* interval between marks in seconds - read-only aft
 ratelimit_t *dflt_ratelimiter = NULL; /* ratelimiter for submits without explicit one */
 uchar *ConfFile = (uchar*) "/etc/rsyslog.conf";
 int bHaveMainQueue = 0;/* set to 1 if the main queue - in queueing mode - is available
-			* If the main queue is either not yet ready or not running in 
+			* If the main queue is either not yet ready or not running in
 			* queueing mode (mode DIRECT!), then this is set to 0.
 			*/
 qqueue_t *pMsgQueue = NULL;	/* default main message queue */
@@ -431,7 +442,7 @@ forkRsyslog(void)
 #endif
 	/* AIXPORT : src support end */
 
-	if(cpid == 0) {    
+	if(cpid == 0) {
 		prepareBackground(pipefd[1]);
 		close(pipefd[0]);
 		return pipefd[1];
@@ -700,7 +711,7 @@ msgConsumer(void __attribute__((unused)) *notNeeded, batch_t *pBatch, wti_t *pWt
 	assert(pBatch != NULL);
 	preprocessBatch(pBatch, pWti->pbShutdownImmediate);
 	ruleset.ProcessBatch(pBatch, pWti);
-//TODO: the BATCH_STATE_COMM must be set somewhere down the road, but we 
+//TODO: the BATCH_STATE_COMM must be set somewhere down the road, but we
 //do not have this yet and so we emulate -- 2010-06-10
 int i;
 	for(i = 0 ; i < pBatch->nElem  && !*pWti->pbShutdownImmediate ; i++) {
@@ -752,7 +763,7 @@ rsRetVal createMainQueue(qqueue_t **ppQueue, uchar *pszQueueName, struct nvlst *
 					ourConf->globals.mainQ.pszMainMsgQFName );
 				if(!ustrcmp(qfn->name, ourConf->globals.mainQ.pszMainMsgQFName)) {
 					snprintf((char*)qfrenamebuf, sizeof(qfrenamebuf), "%d-%s-%s",
-						 ++qfn_renamenum, ourConf->globals.mainQ.pszMainMsgQFName,  
+						 ++qfn_renamenum, ourConf->globals.mainQ.pszMainMsgQFName,
 						 (pszQueueName == NULL) ? "NONAME" : (char*)pszQueueName);
 					qfname = ustrdup(qfrenamebuf);
 					LogError(0, NO_ERRCODE, "Error: queue file name '%s' already in use "
@@ -858,7 +869,7 @@ logmsgInternal_doWrite(smsg_t *pMsg)
 	} else {
 		const int pri = getPRIi(pMsg);
 		uchar *const msg = getMSG(pMsg);
-#		ifdef HAVE_LIBLOGGING_STDLOG
+#		ifdef ENABLE_LIBLOGGING_STDLOG
 		/* the "emit only once" rate limiter is quick and dirty and not
 		 * thread safe. However, that's no problem for the current intend
 		 * and it is not justified to create more robust code for the
@@ -1309,9 +1320,9 @@ initAll(int argc, char **argv)
 	while((ch = getopt(argc, argv, "46ACDdf:i:l:M:nN:qQs:S:T:u:vwx")) != EOF) {
 #endif
 		switch((char)ch) {
-                case '4':
-                case '6':
-                case 'A':
+		case '4':
+		case '6':
+		case 'A':
 		case 'f': /* configuration file */
 		case 'i': /* pid file name */
 		case 'l':
@@ -1330,7 +1341,7 @@ initAll(int argc, char **argv)
 			break;
 #if defined(_AIX)
 		case 'R':  /* This option is a no-op for AIX */
-			break;   
+			break;
 #endif
 		case 'd': /* debug - must be handled now, so that debug is active during init! */
 			debugging_on = 1;
@@ -1383,8 +1394,12 @@ initAll(int argc, char **argv)
 		const char *const tz =
 			(access("/etc/localtime", R_OK) == 0) ? "TZ=/etc/localtime" : "TZ=UTC";
 		putenv((char*)tz);
-		LogMsg(0, RS_RET_NO_TZ_SET, LOG_WARNING, "environment variable TZ is not "
-			"set, auto correcting this to %s\n", tz);
+		if(emitTZWarning) {
+			LogMsg(0, RS_RET_NO_TZ_SET, LOG_WARNING, "environment variable TZ is not "
+				"set, auto correcting this to %s", tz);
+		} else {
+			dbgprintf("environment variable TZ is not set, auto correcting this to %s\n", tz);
+		}
 	}
 
 	/* END core initializations - we now come back to carrying out command line options*/
@@ -1392,24 +1407,24 @@ initAll(int argc, char **argv)
 	while((iRet = bufOptRemove(&ch, &arg)) == RS_RET_OK) {
 		DBGPRINTF("deque option %c, optarg '%s'\n", ch, (arg == NULL) ? "" : arg);
 		switch((char)ch) {
-                case '4':
+		case '4':
 			fprintf (stderr, "rsyslogd: the -4 command line option will go away "
 				 "soon.\nPlease use the global(net.ipprotocol=\"ipv4-only\") "
 				 "configuration parameter instead.\n");
 	                glbl.SetDefPFFamily(PF_INET);
-                        break;
-                case '6':
+			break;
+		case '6':
 			fprintf (stderr, "rsyslogd: the -6 command line option will go away "
 				 "soon.\nPlease use the global(net.ipprotocol=\"ipv6-only\") "
 				 "configuration parameter instead.\n");
-                        glbl.SetDefPFFamily(PF_INET6);
-                        break;
-                case 'A':
+			glbl.SetDefPFFamily(PF_INET6);
+			break;
+		case 'A':
 			fprintf (stderr, "rsyslogd: the -A command line option will go away "
 				 "soon.\n"
 				 "Please use the omfwd parameter \"upd.sendToAll\" instead.\n");
-                        send_to_all++;
-                        break;
+			send_to_all++;
+			break;
 		case 'S':		/* Source IP for local client to be used on multihomed host */
 			fprintf (stderr, "rsyslogd: the -S command line option will go away "
 				 "soon.\n"
@@ -1477,8 +1492,8 @@ initAll(int argc, char **argv)
 				perror("chroot");
 				exit(1);
 			}
-            		if(chdir("/") != 0) {
-                		perror("chdir");
+			if(chdir("/") != 0) {
+				perror("chdir");
 		                exit(1);
 		            }
 			break;
@@ -1514,7 +1529,7 @@ initAll(int argc, char **argv)
 				 "configuration parameter instead.\n");
 			glbl.SetDisableDNS(1);
 			break;
-               case '?':
+		case '?':
 		default:
 			rsyslogd_usage();
 		}
@@ -1552,10 +1567,11 @@ initAll(int argc, char **argv)
 
 	if(hadErrMsgs()) {
 		if(loadConf->globals.bAbortOnUncleanConfig) {
-			fprintf(stderr, "rsyslogd: $AbortOnUncleanConfig is set, and config is not clean.\n"
-					"Check error log for details, fix errors and restart. As a last\n"
-					"resort, you may want to remove $AbortOnUncleanConfig to permit a\n"
-					"startup with a dirty config.\n");
+			fprintf(stderr, "rsyslogd: global(AbortOnUncleanConfig=\"on\") is set, and "
+				"config is not clean.\n"
+				"Check error log for details, fix errors and restart. As a last\n"
+				"resort, you may want to use global(AbortOnUncleanConfig=\"off\") \n"
+				"to permit a startup with a dirty config.\n");
 			exit(2);
 		}
 		if(iConfigVerify) {
@@ -1782,11 +1798,15 @@ rsyslogdDoDie(int sig)
 	static int iRetries = 0; /* debug aid */
 	dbgprintf(MSG1);
 	if(Debug == DEBUG_FULL) {
-		if(write(1, MSG1, sizeof(MSG1) - 1)) {}
+		if(write(1, MSG1, sizeof(MSG1) - 1)) {
+			dbgprintf("%s:%d: write failed\n", __FILE__, __LINE__);
+		}
 	}
 	if(iRetries++ == 4) {
 		if(Debug == DEBUG_FULL) {
-			if(write(1, MSG2, sizeof(MSG2) - 1)) {}
+			if(write(1, MSG2, sizeof(MSG2) - 1)) {
+				dbgprintf("%s:%d: write failed\n", __FILE__, __LINE__);
+			}
 		}
 		abort();
 	}
@@ -1822,8 +1842,25 @@ wait_timeout(void)
 		FD_ZERO(&rfds);
 		FD_SET(SRC_FD, &rfds);
 	}
-	if(!src_exists)
-		select(1, NULL, NULL, NULL, &tvSelectTimeout);
+	if(!src_exists) {
+		/* it looks like select() is NOT interrupted by HUP, even though
+		 * SA_RESTART is not given in the signal setup. As this code is
+		 * not expected to be used in production (when running as a
+		 * service under src control), we simply make a kind of
+		 * "somewhat-busy-wait" algorithm. We compute our own
+		 * timeout value, which we count down to zero. We do this
+		 * in useful subsecond steps.
+		 */
+		const int wait_period = 500000; /* wait period in microseconds */
+		int timeout = janitorInterval * 60 * (1000000 / wait_period);
+		do {
+			if(bFinished || bHadHUP) {
+				break;
+			}
+			srSleep(0, wait_period);
+			timeout--;
+		} while(timeout > 0);
+	}
 	else if(select(SRC_FD + 1, (fd_set *)&rfds, NULL, NULL, &tvSelectTimeout))
 	{
 		if(FD_ISSET(SRC_FD, &rfds))
@@ -1833,9 +1870,10 @@ wait_timeout(void)
 			if (errno != EINTR)
 			{
 				fprintf(stderr,"%s: ERROR: '%d' recvfrom\n", progname,errno);
-				exit(1);
-			} else  /* punt on short read */
-				continue;
+				exit(1); //TODO: this needs to be handled gracefully
+			} else { /* punt on short read */
+				return;
+			}
 
 			switch(srcpacket.subreq.action)
 			{
@@ -2040,7 +2078,7 @@ main(int argc, char **argv)
 		fprintf(stderr, "%s: continuing without SRC support\n", progname);
 		src_exists = FALSE;
 	}
-	if (src_exists) 
+	if (src_exists)
 		if(dup2(0, SRC_FD) == -1) {
 			fprintf(stderr, "%s: dup2 failed exiting now...\n", progname);
 			/* In the unlikely event of dup2 failing we exit */
@@ -2054,6 +2092,8 @@ main(int argc, char **argv)
 			"terminate rsyslog\n", VERSION);
 		PidFile = strdup("NONE"); /* disables pid file writing */
 		glblPermitCtlC = 1;
+		runningInContainer = 1;
+		emitTZWarning = 1;
 	} else {
 		/* "dynamic defaults" - non-container case */
 		PidFile = strdup(PATH_PIDFILE);
@@ -2081,7 +2121,7 @@ main(int argc, char **argv)
 
 	mainloop();
 	deinitAll();
-#ifdef HAVE_LIBLOGGING_STDLOG
+#ifdef ENABLE_LIBLOGGING_STDLOG
 	stdlog_close(stdlog_hdl);
 #endif
 	return 0;
